Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1AudioTranscriptionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Configuration for speech recognition (transcription).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AudioTranscriptionConfig

Returns a new instance of GoogleCloudAiplatformV1beta1AudioTranscriptionConfig.



231
232
233
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adaptation_phrasesArray<String>

Optional. Deprecated: Use custom_vocabulary instead. A list of phrases to bias the speech recognition model towards. Corresponds to the JSON property adaptationPhrases

Returns:

  • (Array<String>)


193
194
195
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 193

def adaptation_phrases
  @adaptation_phrases
end

#custom_vocabularyArray<String>

Optional. A list of custom vocabulary phrases to bias the speech recognition model toward recognizing specific terms. Corresponds to the JSON property customVocabulary

Returns:

  • (Array<String>)


199
200
201
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 199

def custom_vocabulary
  @custom_vocabulary
end

#diarizationBoolean Also known as: diarization?

Optional. Configures speaker diarization. Corresponds to the JSON property diarization

Returns:

  • (Boolean)


204
205
206
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 204

def diarization
  @diarization
end

#language_autoGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1AudioTranscriptionConfigLanguageAuto

Deprecated: Use top-level language_codes instead. Indicates the language of the audio should be automatically detected. Corresponds to the JSON property languageAuto



211
212
213
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 211

def language_auto
  @language_auto
end

#language_codesArray<String>

Optional. BCP-47 language codes providing hints about the languages present in the audio. If omitted or empty, defaults to automatic language detection. Corresponds to the JSON property languageCodes

Returns:

  • (Array<String>)


217
218
219
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 217

def language_codes
  @language_codes
end

#language_hintsGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1AudioTranscriptionConfigLanguageHints

Deprecated: Use top-level language_codes instead. Provides hints to the model about possible languages present in the audio. Corresponds to the JSON property languageHints



223
224
225
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 223

def language_hints
  @language_hints
end

#word_timestampBoolean Also known as: word_timestamp?

Optional. Configures word-level timestamp generation. Corresponds to the JSON property wordTimestamp

Returns:

  • (Boolean)


228
229
230
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 228

def word_timestamp
  @word_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



236
237
238
239
240
241
242
243
244
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 236

def update!(**args)
  @adaptation_phrases = args[:adaptation_phrases] if args.key?(:adaptation_phrases)
  @custom_vocabulary = args[:custom_vocabulary] if args.key?(:custom_vocabulary)
  @diarization = args[:diarization] if args.key?(:diarization)
  @language_auto = args[:language_auto] if args.key?(:language_auto)
  @language_codes = args[:language_codes] if args.key?(:language_codes)
  @language_hints = args[:language_hints] if args.key?(:language_hints)
  @word_timestamp = args[:word_timestamp] if args.key?(:word_timestamp)
end