Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Candidate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

A response candidate generated from the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Candidate

Returns a new instance of GoogleCloudAiplatformV1beta1Candidate.



613
614
615
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avg_logprobsFloat

Output only. The average log probability of the tokens in this candidate. This is a length-normalized score that can be used to compare the quality of candidates of different lengths. A higher average log probability suggests a more confident and coherent response. Corresponds to the JSON property avgLogprobs

Returns:

  • (Float)


551
552
553
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 551

def avg_logprobs
  @avg_logprobs
end

#citation_metadataGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1CitationMetadata

A collection of citations that apply to a piece of generated content. Corresponds to the JSON property citationMetadata



556
557
558
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 556

def 
  @citation_metadata
end

#contentGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



563
564
565
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 563

def content
  @content
end

#finish_messageString

Output only. Describes the reason the model stopped generating tokens in more detail. This field is returned only when finish_reason is set. Corresponds to the JSON property finishMessage

Returns:

  • (String)


569
570
571
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 569

def finish_message
  @finish_message
end

#finish_reasonString

Output only. The reason why the model stopped generating tokens. If empty, the model has not stopped generating. Corresponds to the JSON property finishReason

Returns:

  • (String)


575
576
577
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 575

def finish_reason
  @finish_reason
end

#grounding_metadataGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingMetadata

Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources. Corresponds to the JSON property groundingMetadata



582
583
584
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 582

def 
  @grounding_metadata
end

#indexFixnum

Output only. The 0-based index of this candidate in the list of generated responses. This is useful for distinguishing between multiple candidates when candidate_count > 1. Corresponds to the JSON property index

Returns:

  • (Fixnum)


589
590
591
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 589

def index
  @index
end

#logprobs_resultGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1LogprobsResult

The log probabilities of the tokens generated by the model. This is useful for understanding the model's confidence in its predictions and for debugging. For example, you can use log probabilities to identify when the model is making a less confident prediction or to explore alternative responses that the model considered. A low log probability can also indicate that the model is " hallucinating" or generating factually incorrect information. Corresponds to the JSON property logprobsResult



599
600
601
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 599

def logprobs_result
  @logprobs_result
end

#safety_ratingsArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1SafetyRating>

Output only. A list of ratings for the safety of a response candidate. There is at most one rating per category. Corresponds to the JSON property safetyRatings



605
606
607
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 605

def safety_ratings
  @safety_ratings
end

#url_context_metadataGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1UrlContextMetadata

Metadata returned when the model uses the url_context tool to get information from a user-provided URL. Corresponds to the JSON property urlContextMetadata



611
612
613
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 611

def 
  @url_context_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



618
619
620
621
622
623
624
625
626
627
628
629
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 618

def update!(**args)
  @avg_logprobs = args[:avg_logprobs] if args.key?(:avg_logprobs)
  @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata)
  @content = args[:content] if args.key?(:content)
  @finish_message = args[:finish_message] if args.key?(:finish_message)
  @finish_reason = args[:finish_reason] if args.key?(:finish_reason)
  @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata)
  @index = args[:index] if args.key?(:index)
  @logprobs_result = args[:logprobs_result] if args.key?(:logprobs_result)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
  @url_context_metadata = args[:url_context_metadata] if args.key?(:url_context_metadata)
end