Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Citation
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Citation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
A citation for a piece of generatedcontent.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
Output only.
-
#license ⇒ String
Output only.
-
#publication_date ⇒ Google::Apis::FirebasemlV2beta::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_index ⇒ Fixnum
Output only.
-
#title ⇒ String
Output only.
-
#uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Citation
constructor
A new instance of GoogleCloudAiplatformV1beta1Citation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Citation
Returns a new instance of GoogleCloudAiplatformV1beta1Citation.
523 524 525 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 523 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
Output only. The end index of the citation in the content.
Corresponds to the JSON property endIndex
489 490 491 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 489 def end_index @end_index end |
#license ⇒ String
Output only. The license of the source of the citation.
Corresponds to the JSON property license
494 495 496 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 494 def license @license end |
#publication_date ⇒ Google::Apis::FirebasemlV2beta::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property publicationDate
506 507 508 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 506 def publication_date @publication_date end |
#start_index ⇒ Fixnum
Output only. The start index of the citation in the content.
Corresponds to the JSON property startIndex
511 512 513 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 511 def start_index @start_index end |
#title ⇒ String
Output only. The title of the source of the citation.
Corresponds to the JSON property title
516 517 518 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 516 def title @title end |
#uri ⇒ String
Output only. The URI of the source of the citation.
Corresponds to the JSON property uri
521 522 523 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 521 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
528 529 530 531 532 533 534 535 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 528 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @license = args[:license] if args.key?(:license) @publication_date = args[:publication_date] if args.key?(:publication_date) @start_index = args[:start_index] if args.key?(:start_index) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |