Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1CodeExecutionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Result of executing the [ExecutableCode]. Only generated when using the [ CodeExecution] tool, and always follows a part containing the [ ExecutableCode].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CodeExecutionResult

Returns a new instance of GoogleCloudAiplatformV1beta1CodeExecutionResult.



536
537
538
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#outcomeString

Required. Outcome of the code execution. Corresponds to the JSON property outcome

Returns:

  • (String)


528
529
530
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 528

def outcome
  @outcome
end

#outputString

Optional. Contains stdout when code execution is successful, stderr or other description otherwise. Corresponds to the JSON property output

Returns:

  • (String)


534
535
536
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 534

def output
  @output
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



541
542
543
544
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 541

def update!(**args)
  @outcome = args[:outcome] if args.key?(:outcome)
  @output = args[:output] if args.key?(:output)
end