Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExecutableCode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the CodeExecution tool, in which the code will be automatically executed, and a corresponding CodeExecutionResult will also be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode

Returns a new instance of GoogleCloudAiplatformV1beta1ExecutableCode.



951
952
953
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 951

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Required. The code to be executed. Corresponds to the JSON property code

Returns:

  • (String)


938
939
940
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 938

def code
  @code
end

#idString

Optional. Unique identifier of the ExecutableCode part. The server returns the CodeExecutionResult with the matching id. Corresponds to the JSON property id

Returns:

  • (String)


944
945
946
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 944

def id
  @id
end

#languageString

Required. Programming language of the code. Corresponds to the JSON property language

Returns:

  • (String)


949
950
951
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 949

def language
  @language
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



956
957
958
959
960
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 956

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @id = args[:id] if args.key?(:id)
  @language = args[:language] if args.key?(:language)
end