Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExternalApi

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Retrieve from data source powered by external API for grounding. The external API is not owned by Google, but need to follow the pre-defined API spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExternalApi

Returns a new instance of GoogleCloudAiplatformV1beta1ExternalApi.



988
989
990
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_authGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ApiAuth

The generic reusable api auth config. Deprecated. Please use AuthConfig ( google/cloud/aiplatform/master/auth.proto) instead. Corresponds to the JSON property apiAuth



959
960
961
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 959

def api_auth
  @api_auth
end

#api_specString

The API spec that the external API implements. Corresponds to the JSON property apiSpec

Returns:

  • (String)


964
965
966
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 964

def api_spec
  @api_spec
end

#auth_configGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1AuthConfig

Auth configuration to run the extension. Corresponds to the JSON property authConfig



969
970
971
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 969

def auth_config
  @auth_config
end

#elastic_search_paramsGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExternalApiElasticSearchParams

The search parameters to use for the ELASTIC_SEARCH spec. Corresponds to the JSON property elasticSearchParams



974
975
976
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 974

def elastic_search_params
  @elastic_search_params
end

#endpointString

The endpoint of the external API. The system will call the API at this endpoint to retrieve the data for grounding. Example: https://acme.com:443/ search Corresponds to the JSON property endpoint

Returns:

  • (String)


981
982
983
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 981

def endpoint
  @endpoint
end

#simple_search_paramsGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExternalApiSimpleSearchParams

The search parameters to use for SIMPLE_SEARCH spec. Corresponds to the JSON property simpleSearchParams



986
987
988
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 986

def simple_search_params
  @simple_search_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



993
994
995
996
997
998
999
1000
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 993

def update!(**args)
  @api_auth = args[:api_auth] if args.key?(:api_auth)
  @api_spec = args[:api_spec] if args.key?(:api_spec)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @elastic_search_params = args[:elastic_search_params] if args.key?(:elastic_search_params)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @simple_search_params = args[:simple_search_params] if args.key?(:simple_search_params)
end