Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FileData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

URI-based data. A FileData message contains a URI pointing to data of a specific media type. It is used to represent images, audio, and video stored in Google Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FileData

Returns a new instance of GoogleCloudAiplatformV1beta1FileData.



1085
1086
1087
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of the file. Used to provide a label or filename to distinguish files. This field is only returned in PromptMessage for prompt management. It is used in the Gemini calls only when server side tools ( code_execution, google_search, and url_context) are enabled. Corresponds to the JSON property displayName

Returns:

  • (String)


1073
1074
1075
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1073

def display_name
  @display_name
end

#file_uriString

Required. The URI of the file in Google Cloud Storage. Corresponds to the JSON property fileUri

Returns:

  • (String)


1078
1079
1080
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1078

def file_uri
  @file_uri
end

#mime_typeString

Required. The IANA standard MIME type of the source data. Corresponds to the JSON property mimeType

Returns:

  • (String)


1083
1084
1085
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1083

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1090
1091
1092
1093
1094
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1090

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @file_uri = args[:file_uri] if args.key?(:file_uri)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end