Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionCallingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Function calling config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionCallingConfig

Returns a new instance of GoogleCloudAiplatformV1beta1FunctionCallingConfig.



994
995
996
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_function_namesArray<String>

Optional. Function names to call. Only set when the Mode is ANY. Function names should match FunctionDeclaration.name. With mode set to ANY, model will predict a function call from the set of function names provided. Corresponds to the JSON property allowedFunctionNames

Returns:

  • (Array<String>)


979
980
981
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 979

def allowed_function_names
  @allowed_function_names
end

#modeString

Optional. Function calling mode. Corresponds to the JSON property mode

Returns:

  • (String)


984
985
986
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 984

def mode
  @mode
end

#stream_function_call_argumentsBoolean Also known as: stream_function_call_arguments?

Optional. When set to true, arguments of a single function call will be streamed out in multiple parts/contents/responses. Partial parameter results will be returned in the FunctionCall.partial_args field. Corresponds to the JSON property streamFunctionCallArguments

Returns:

  • (Boolean)


991
992
993
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 991

def stream_function_call_arguments
  @stream_function_call_arguments
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



999
1000
1001
1002
1003
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 999

def update!(**args)
  @allowed_function_names = args[:allowed_function_names] if args.key?(:allowed_function_names)
  @mode = args[:mode] if args.key?(:mode)
  @stream_function_call_arguments = args[:stream_function_call_arguments] if args.key?(:stream_function_call_arguments)
end