Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionResponseBlob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Raw media bytes for function response. Text should not be sent as raw bytes, use the 'text' field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionResponseBlob

Returns a new instance of GoogleCloudAiplatformV1beta1FunctionResponseBlob.



1157
1158
1159
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

Required. Raw bytes. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1142
1143
1144
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1142

def data
  @data
end

#display_nameString

Optional. Display name of the blob. Used to provide a label or filename to distinguish blobs. This field is only returned in PromptMessage for prompt management. It is currently used in the Gemini GenerateContent calls only when server side tools (code_execution, google_search, and url_context) are enabled. Corresponds to the JSON property displayName

Returns:

  • (String)


1150
1151
1152
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1150

def display_name
  @display_name
end

#mime_typeString

Required. The IANA standard MIME type of the source data. Corresponds to the JSON property mimeType

Returns:

  • (String)


1155
1156
1157
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1155

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1162
1163
1164
1165
1166
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1162

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @display_name = args[:display_name] if args.key?(:display_name)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end