Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
The configuration for routing the request to a specific model. This can be used to control which model is used for the generation, either automatically or by specifying a model name.
Instance Attribute Summary collapse
-
#auto_mode ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode
The configuration for automated routing.
-
#manual_mode ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigManualRoutingMode
The configuration for manual routing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig
Returns a new instance of GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfig.
1936 1937 1938 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1936 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_mode ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode
The configuration for automated routing. When automated routing is specified,
the routing will be determined by the pretrained routing model and customer
provided model routing preference.
Corresponds to the JSON property autoMode
1928 1929 1930 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1928 def auto_mode @auto_mode end |
#manual_mode ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigManualRoutingMode
The configuration for manual routing. When manual routing is specified, the
model will be selected based on the model name provided.
Corresponds to the JSON property manualMode
1934 1935 1936 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1934 def manual_mode @manual_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1941 1942 1943 1944 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1941 def update!(**args) @auto_mode = args[:auto_mode] if args.key?(:auto_mode) @manual_mode = args[:manual_mode] if args.key?(:manual_mode) end |