Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

An Image chunk is a piece of evidence that comes from an image search result. It contains the URI of the image search result and the URI of the image. This is used to provide the user with a link to the source of the information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkImage

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkImage.



2219
2220
2221
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2219

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

The domain of the image search result page. Corresponds to the JSON property domain

Returns:

  • (String)


2202
2203
2204
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2202

def domain
  @domain
end

#image_uriString

The URI of the image. Corresponds to the JSON property imageUri

Returns:

  • (String)


2207
2208
2209
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2207

def image_uri
  @image_uri
end

#source_uriString

The URI of the image search result page. Corresponds to the JSON property sourceUri

Returns:

  • (String)


2212
2213
2214
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2212

def source_uri
  @source_uri
end

#titleString

The title of the image search result page. Corresponds to the JSON property title

Returns:

  • (String)


2217
2218
2219
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2217

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2224
2225
2226
2227
2228
2229
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2224

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @title = args[:title] if args.key?(:title)
end