Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Context retrieved from a data source to ground the model's response. This is used when a retrieval tool fetches information from a user-provided corpus or a public dataset.
Instance Attribute Summary collapse
-
#document_name ⇒ String
Output only.
-
#rag_chunk ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
-
#text ⇒ String
The content of the retrieved data source.
-
#title ⇒ String
The title of the retrieved data source.
-
#uri ⇒ String
The URI of the retrieved data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext.
2161 2162 2163 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2161 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_name ⇒ String
Output only. The full resource name of the referenced Vertex AI Search
document. This is used to identify the specific document that was retrieved.
The format is projects/project/locations/location/collections/collection
/dataStores/data_store/branches/branch/documents/document`.
Corresponds to the JSON propertydocumentName`
2138 2139 2140 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2138 def document_name @document_name end |
#rag_chunk ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated
metadata.
Corresponds to the JSON property ragChunk
2144 2145 2146 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2144 def rag_chunk @rag_chunk end |
#text ⇒ String
The content of the retrieved data source.
Corresponds to the JSON property text
2149 2150 2151 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2149 def text @text end |
#title ⇒ String
The title of the retrieved data source.
Corresponds to the JSON property title
2154 2155 2156 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2154 def title @title end |
#uri ⇒ String
The URI of the retrieved data source.
Corresponds to the JSON property uri
2159 2160 2161 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2159 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2166 2167 2168 2169 2170 2171 2172 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2166 def update!(**args) @document_name = args[:document_name] if args.key?(:document_name) @rag_chunk = args[:rag_chunk] if args.key?(:rag_chunk) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |