Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkWeb
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkWeb
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
A Web chunk is a piece of evidence that comes from a web page. It contains
the URI of the web page, the title of the page, and the domain of the page.
This is used to provide the user with a link to the source of the information.
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain of the web page that contains the evidence.
-
#title ⇒ String
The title of the web page that contains the evidence.
-
#uri ⇒ String
The URI of the web page that contains the evidence.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkWeb
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkWeb.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkWeb
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkWeb.
2197 2198 2199 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2197 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
The domain of the web page that contains the evidence. This can be used to
filter out low-quality sources.
Corresponds to the JSON property domain
2185 2186 2187 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2185 def domain @domain end |
#title ⇒ String
The title of the web page that contains the evidence.
Corresponds to the JSON property title
2190 2191 2192 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2190 def title @title end |
#uri ⇒ String
The URI of the web page that contains the evidence.
Corresponds to the JSON property uri
2195 2196 2197 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2195 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2202 2203 2204 2205 2206 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2202 def update!(**args) @domain = args[:domain] if args.key?(:domain) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |