Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

A RagChunk includes the content of a chunk of a RagFile, and associated metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagChunk

Returns a new instance of GoogleCloudAiplatformV1beta1RagChunk.



3135
3136
3137
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3135

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_idString

The ID of the chunk. Corresponds to the JSON property chunkId

Returns:

  • (String)


3118
3119
3120
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3118

def chunk_id
  @chunk_id
end

#file_idString

The ID of the file that the chunk belongs to. Corresponds to the JSON property fileId

Returns:

  • (String)


3123
3124
3125
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3123

def file_id
  @file_id
end

#page_spanGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunkPageSpan

Represents where the chunk starts and ends in the document. Corresponds to the JSON property pageSpan



3128
3129
3130
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3128

def page_span
  @page_span
end

#textString

The content of the chunk. Corresponds to the JSON property text

Returns:

  • (String)


3133
3134
3135
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3133

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3140
3141
3142
3143
3144
3145
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3140

def update!(**args)
  @chunk_id = args[:chunk_id] if args.key?(:chunk_id)
  @file_id = args[:file_id] if args.key?(:file_id)
  @page_span = args[:page_span] if args.key?(:page_span)
  @text = args[:text] if args.key?(:text)
end