Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Retrieval
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Retrieval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Defines a retrieval tool that model can call to access external knowledge.
Instance Attribute Summary collapse
-
#disable_attribution ⇒ Boolean
(also: #disable_attribution?)
Optional.
-
#external_api ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExternalApi
Retrieve from data source powered by external API for grounding.
-
#vertex_ai_search ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VertexAiSearch
Retrieve from Vertex AI Search datastore or engine for grounding.
-
#vertex_rag_store ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VertexRagStore
Retrieve from Vertex RAG Store for grounding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Retrieval
constructor
A new instance of GoogleCloudAiplatformV1beta1Retrieval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Retrieval
Returns a new instance of GoogleCloudAiplatformV1beta1Retrieval.
2906 2907 2908 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_attribution ⇒ Boolean Also known as: disable_attribution?
Optional. Deprecated. This option is no longer supported.
Corresponds to the JSON property disableAttribution
2885 2886 2887 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2885 def disable_attribution @disable_attribution end |
#external_api ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExternalApi
Retrieve from data source powered by external API for grounding. The external
API is not owned by Google, but need to follow the pre-defined API spec.
Corresponds to the JSON property externalApi
2892 2893 2894 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2892 def external_api @external_api end |
#vertex_ai_search ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VertexAiSearch
Retrieve from Vertex AI Search datastore or engine for grounding. datastore
and engine are mutually exclusive. See https://cloud.google.com/products/agent-
builder
Corresponds to the JSON property vertexAiSearch
2899 2900 2901 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2899 def vertex_ai_search @vertex_ai_search end |
#vertex_rag_store ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VertexRagStore
Retrieve from Vertex RAG Store for grounding.
Corresponds to the JSON property vertexRagStore
2904 2905 2906 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2904 def vertex_rag_store @vertex_rag_store end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2911 2912 2913 2914 2915 2916 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2911 def update!(**args) @disable_attribution = args[:disable_attribution] if args.key?(:disable_attribution) @external_api = args[:external_api] if args.key?(:external_api) @vertex_ai_search = args[:vertex_ai_search] if args.key?(:vertex_ai_search) @vertex_rag_store = args[:vertex_rag_store] if args.key?(:vertex_rag_store) end |