Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RetrievalMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RetrievalMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Metadata related to the retrieval grounding source. This is part of the
GroundingMetadata returned when grounding is enabled.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrievalMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1RetrievalMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrievalMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1RetrievalMetadata.
2962 2963 2964 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2962 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_search_dynamic_retrieval_score ⇒ Float
Optional. A score indicating how likely it is that a Google Search query could
help answer the prompt. The score is in the range of [0, 1]. A score of 1
means the model is confident that a search will be helpful, and 0 means it is
not. This score is populated only when Google Search grounding and dynamic
retrieval are enabled. The score is used to determine whether to trigger a
search.
Corresponds to the JSON property googleSearchDynamicRetrievalScore
2960 2961 2962 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2960 def google_search_dynamic_retrieval_score @google_search_dynamic_retrieval_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2967 2968 2969 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2967 def update!(**args) @google_search_dynamic_retrieval_score = args[:google_search_dynamic_retrieval_score] if args.key?(:google_search_dynamic_retrieval_score) end |