Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Segment
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Segment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
A segment of the content.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
Output only.
-
#part_index ⇒ Fixnum
Output only.
-
#start_index ⇒ Fixnum
Output only.
-
#text ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Segment
constructor
A new instance of GoogleCloudAiplatformV1beta1Segment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Segment
Returns a new instance of GoogleCloudAiplatformV1beta1Segment.
3846 3847 3848 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3846 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
Output only. The end index of the segment in the Part, measured in bytes.
This marks the end of the segment and is exclusive, meaning the segment
includes content up to, but not including, the byte at this index.
Corresponds to the JSON property endIndex
3826 3827 3828 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3826 def end_index @end_index end |
#part_index ⇒ Fixnum
Output only. The index of the Part object that this segment belongs to. This
is useful for associating the segment with a specific part of the content.
Corresponds to the JSON property partIndex
3832 3833 3834 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3832 def part_index @part_index end |
#start_index ⇒ Fixnum
Output only. The start index of the segment in the Part, measured in bytes.
This marks the beginning of the segment and is inclusive, meaning the byte at
this index is the first byte of the segment.
Corresponds to the JSON property startIndex
3839 3840 3841 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3839 def start_index @start_index end |
#text ⇒ String
Output only. The text of the segment.
Corresponds to the JSON property text
3844 3845 3846 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3844 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3851 3852 3853 3854 3855 3856 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3851 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @part_index = args[:part_index] if args.key?(:part_index) @start_index = args[:start_index] if args.key?(:start_index) @text = args[:text] if args.key?(:text) end |