Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Tool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Tool details that the model may use to generate response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. A Tool object should contain exactly one type of Tool (e.g FunctionDeclaration, Retrieval or GoogleSearchRetrieval).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tool

Returns a new instance of GoogleCloudAiplatformV1beta1Tool.



4015
4016
4017
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_executionGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolCodeExecution

Tool that executes code generated by the model, and automatically returns the result to the model. See also ExecutableCode and CodeExecutionResult, which are input and output to this tool. Corresponds to the JSON property codeExecution



3955
3956
3957
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3955

def code_execution
  @code_execution
end

#computer_useGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolComputerUse

Tool to support computer use. Corresponds to the JSON property computerUse



3960
3961
3962
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3960

def computer_use
  @computer_use
end

#enterprise_web_searchGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1EnterpriseWebSearch

Tool to search public web data, powered by Vertex AI Search and Sec4 compliance. Corresponds to the JSON property enterpriseWebSearch



3966
3967
3968
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3966

def enterprise_web_search
  @enterprise_web_search
end

#exa_ai_searchGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolExaAiSearch

ExaAiSearch tool type. A tool that uses the Exa.ai search engine for grounding. Corresponds to the JSON property exaAiSearch



3971
3972
3973
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3971

def exa_ai_search
  @exa_ai_search
end

#function_declarationsArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionDeclaration>

Optional. Function tool type. One or more function declarations to be passed to the model along with the current user query. Model may decide to call a subset of these functions by populating FunctionCall in the response. User should provide a FunctionResponse for each function call in the next turn. Based on the function responses, Model will generate the final response back to the user. Maximum 512 function declarations can be provided. Corresponds to the JSON property functionDeclarations



3981
3982
3983
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3981

def function_declarations
  @function_declarations
end

#google_mapsGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GoogleMaps

Tool to retrieve public maps data for grounding, powered by Google. Corresponds to the JSON property googleMaps



3986
3987
3988
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3986

def google_maps
  @google_maps
end

#google_searchGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolGoogleSearch

GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google. Corresponds to the JSON property googleSearch



3992
3993
3994
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3992

def google_search
  @google_search
end

#google_search_retrievalGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GoogleSearchRetrieval

Tool to retrieve public web data for grounding, powered by Google. Corresponds to the JSON property googleSearchRetrieval



3997
3998
3999
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3997

def google_search_retrieval
  @google_search_retrieval
end

#parallel_ai_searchGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolParallelAiSearch

ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding. Corresponds to the JSON property parallelAiSearch



4003
4004
4005
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4003

def parallel_ai_search
  @parallel_ai_search
end

#retrievalGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Retrieval

Defines a retrieval tool that model can call to access external knowledge. Corresponds to the JSON property retrieval



4008
4009
4010
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4008

def retrieval
  @retrieval
end

#url_contextGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1UrlContext

Tool to support URL context. Corresponds to the JSON property urlContext



4013
4014
4015
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4013

def url_context
  @url_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4020

def update!(**args)
  @code_execution = args[:code_execution] if args.key?(:code_execution)
  @computer_use = args[:computer_use] if args.key?(:computer_use)
  @enterprise_web_search = args[:enterprise_web_search] if args.key?(:enterprise_web_search)
  @exa_ai_search = args[:exa_ai_search] if args.key?(:exa_ai_search)
  @function_declarations = args[:function_declarations] if args.key?(:function_declarations)
  @google_maps = args[:google_maps] if args.key?(:google_maps)
  @google_search = args[:google_search] if args.key?(:google_search)
  @google_search_retrieval = args[:google_search_retrieval] if args.key?(:google_search_retrieval)
  @parallel_ai_search = args[:parallel_ai_search] if args.key?(:parallel_ai_search)
  @retrieval = args[:retrieval] if args.key?(:retrieval)
  @url_context = args[:url_context] if args.key?(:url_context)
end