Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolCodeExecution
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolCodeExecution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Tool that executes code generated by the model, and automatically returns the result to the model. See also ExecutableCode and CodeExecutionResult, which are input and output to this tool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolCodeExecution
constructor
A new instance of GoogleCloudAiplatformV1beta1ToolCodeExecution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolCodeExecution
Returns a new instance of GoogleCloudAiplatformV1beta1ToolCodeExecution.
4041 4042 4043 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4041 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4046 4047 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4046 def update!(**args) end |