Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolGoogleSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolGoogleSearch

Returns a new instance of GoogleCloudAiplatformV1beta1ToolGoogleSearch.



3754
3755
3756
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocking_confidenceString

Optional. Sites with confidence level chosen & above this value will be blocked from the search results. Corresponds to the JSON property blockingConfidence

Returns:

  • (String)


3741
3742
3743
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3741

def blocking_confidence
  @blocking_confidence
end

#exclude_domainsArray<String>

Optional. List of domains to be excluded from the search results. The default limit is 2000 domains. Example: ["amazon.com", "facebook.com"]. Corresponds to the JSON property excludeDomains

Returns:

  • (Array<String>)


3747
3748
3749
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3747

def exclude_domains
  @exclude_domains
end

#search_typesGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolGoogleSearchSearchTypes

Different types of search that can be enabled on the GoogleSearch tool. Corresponds to the JSON property searchTypes



3752
3753
3754
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3752

def search_types
  @search_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3759
3760
3761
3762
3763
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3759

def update!(**args)
  @blocking_confidence = args[:blocking_confidence] if args.key?(:blocking_confidence)
  @exclude_domains = args[:exclude_domains] if args.key?(:exclude_domains)
  @search_types = args[:search_types] if args.key?(:search_types)
end