Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolParallelAiSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolParallelAiSearch

Returns a new instance of GoogleCloudAiplatformV1beta1ToolParallelAiSearch.



4269
4270
4271
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4269

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_keyString

Optional. The API key for ParallelAiSearch. If an API key is not provided, the system will attempt to verify access by checking for an active Parallel.ai subscription through the Google Cloud Marketplace. See https://docs.parallel. ai/search/search-quickstart for more details. Corresponds to the JSON property apiKey

Returns:

  • (String)


4236
4237
4238
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4236

def api_key
  @api_key
end

#custom_configsHash<String,Object>

Optional. Custom configs for ParallelAiSearch. This field can be used to pass any parameter from the Parallel.ai Search API. See the Parallel.ai documentation for the full list of available parameters and their usage: https: //docs.parallel.ai/api-reference/search-beta/search Currently only source_policy, excerpts, max_results, mode, fetch_policy can be set via this field. For example: "source_policy": "include_domains": ["google. com", "wikipedia.org"], "exclude_domains": ["example.com"] , "fetch_policy": "max_age_seconds": 3600 Corresponds to the JSON property customConfigs

Returns:

  • (Hash<String,Object>)


4248
4249
4250
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4248

def custom_configs
  @custom_configs
end

#enable_data_retentionBoolean Also known as: enable_data_retention?

Optional. Deprecated: Use enable_zero_data_retention instead. Instructs Vertex Grounding to use Parallel's Zero Data Retention Marketplace product. If this value is "false" or omitted, the Parallel Web Search for Grounding standard subscription will be used. If this value is "true", the Parallel Web Search for Grounding - ZDR subscription will be used. Corresponds to the JSON property enableDataRetention

Returns:

  • (Boolean)


4257
4258
4259
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4257

def enable_data_retention
  @enable_data_retention
end

#enable_zero_data_retentionBoolean Also known as: enable_zero_data_retention?

Optional. Instructs Vertex Grounding to use Parallel's Zero Data Retention Marketplace product. If this value is "false" or omitted, the Parallel Web Search for Grounding standard subscription will be used. If this value is " true", the Parallel Web Search for Grounding - ZDR subscription will be used. Corresponds to the JSON property enableZeroDataRetention

Returns:

  • (Boolean)


4266
4267
4268
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4266

def enable_zero_data_retention
  @enable_zero_data_retention
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4274
4275
4276
4277
4278
4279
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4274

def update!(**args)
  @api_key = args[:api_key] if args.key?(:api_key)
  @custom_configs = args[:custom_configs] if args.key?(:custom_configs)
  @enable_data_retention = args[:enable_data_retention] if args.key?(:enable_data_retention)
  @enable_zero_data_retention = args[:enable_zero_data_retention] if args.key?(:enable_zero_data_retention)
end