Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VertexAiSearch
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VertexAiSearch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Retrieve from Vertex AI Search datastore or engine for grounding. datastore and engine are mutually exclusive. See https://cloud.google.com/products/agent- builder
Instance Attribute Summary collapse
-
#data_store_specs ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VertexAiSearchDataStoreSpec>
Specifications that define the specific DataStores to be searched, along with configurations for those data stores.
-
#datastore ⇒ String
Optional.
-
#engine ⇒ String
Optional.
-
#filter ⇒ String
Optional.
-
#max_results ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VertexAiSearch
constructor
A new instance of GoogleCloudAiplatformV1beta1VertexAiSearch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VertexAiSearch
Returns a new instance of GoogleCloudAiplatformV1beta1VertexAiSearch.
4379 4380 4381 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store_specs ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VertexAiSearchDataStoreSpec>
Specifications that define the specific DataStores to be searched, along with
configurations for those data stores. This is only considered for Engines with
multiple data stores. It should only be set if engine is used.
Corresponds to the JSON property dataStoreSpecs
4352 4353 4354 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4352 def data_store_specs @data_store_specs end |
#datastore ⇒ String
Optional. Fully-qualified Vertex AI Search data store resource ID. Format:
projects/project/locations/location/collections/collection/dataStores/
dataStore`
Corresponds to the JSON propertydatastore`
4359 4360 4361 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4359 def datastore @datastore end |
#engine ⇒ String
Optional. Fully-qualified Vertex AI Search engine resource ID. Format:
projects/project/locations/location/collections/collection/engines/
engine`
Corresponds to the JSON propertyengine`
4366 4367 4368 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4366 def engine @engine end |
#filter ⇒ String
Optional. Filter strings to be passed to the search API.
Corresponds to the JSON property filter
4371 4372 4373 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4371 def filter @filter end |
#max_results ⇒ Fixnum
Optional. Number of search results to return per query. The default value is
- The maximumm allowed value is 10.
Corresponds to the JSON property
maxResults
4377 4378 4379 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4377 def max_results @max_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4384 4385 4386 4387 4388 4389 4390 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4384 def update!(**args) @data_store_specs = args[:data_store_specs] if args.key?(:data_store_specs) @datastore = args[:datastore] if args.key?(:datastore) @engine = args[:engine] if args.key?(:engine) @filter = args[:filter] if args.key?(:filter) @max_results = args[:max_results] if args.key?(:max_results) end |