Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VideoMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Provides metadata for a video, including the start and end offsets for clipping and the frame rate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VideoMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1VideoMetadata.



4255
4256
4257
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_offsetString

Optional. The end offset of the video. Corresponds to the JSON property endOffset

Returns:

  • (String)


4242
4243
4244
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4242

def end_offset
  @end_offset
end

#fpsFloat

Optional. The frame rate of the video sent to the model. If not specified, the default value is 1.0. The valid range is (0.0, 24.0]. Corresponds to the JSON property fps

Returns:

  • (Float)


4248
4249
4250
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4248

def fps
  @fps
end

#start_offsetString

Optional. The start offset of the video. Corresponds to the JSON property startOffset

Returns:

  • (String)


4253
4254
4255
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4253

def start_offset
  @start_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4260
4261
4262
4263
4264
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4260

def update!(**args)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @fps = args[:fps] if args.key?(:fps)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
end