Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1AudioTranscriptionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Configuration for speech recognition (transcription).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AudioTranscriptionConfig

Returns a new instance of GoogleCloudAiplatformV1beta1AudioTranscriptionConfig.



222
223
224
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 222

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adaptation_phrasesArray<String>

Optional. A list of phrases to bias the ASR model towards. Corresponds to the JSON property adaptationPhrases

Returns:

  • (Array<String>)


192
193
194
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 192

def adaptation_phrases
  @adaptation_phrases
end

#custom_vocabularyArray<String>

Optional. A list of custom vocabulary phrases to bias the speech recognition model toward recognizing specific terms. Corresponds to the JSON property customVocabulary

Returns:

  • (Array<String>)


198
199
200
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 198

def custom_vocabulary
  @custom_vocabulary
end

#diarizationBoolean Also known as: diarization?

Optional. Configures speaker diarization. Corresponds to the JSON property diarization

Returns:

  • (Boolean)


203
204
205
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 203

def diarization
  @diarization
end

#language_autoGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1AudioTranscriptionConfigLanguageAuto

Indicates the language of the audio should be automatically detected. Corresponds to the JSON property languageAuto



209
210
211
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 209

def language_auto
  @language_auto
end

#language_hintsGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1AudioTranscriptionConfigLanguageHints

Provides hints to the model about possible languages present in the audio. Corresponds to the JSON property languageHints



214
215
216
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 214

def language_hints
  @language_hints
end

#word_timestampBoolean Also known as: word_timestamp?

Optional. Configures word-level timestamp generation. Corresponds to the JSON property wordTimestamp

Returns:

  • (Boolean)


219
220
221
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 219

def word_timestamp
  @word_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



227
228
229
230
231
232
233
234
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 227

def update!(**args)
  @adaptation_phrases = args[:adaptation_phrases] if args.key?(:adaptation_phrases)
  @custom_vocabulary = args[:custom_vocabulary] if args.key?(:custom_vocabulary)
  @diarization = args[:diarization] if args.key?(:diarization)
  @language_auto = args[:language_auto] if args.key?(:language_auto)
  @language_hints = args[:language_hints] if args.key?(:language_hints)
  @word_timestamp = args[:word_timestamp] if args.key?(:word_timestamp)
end