Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1AudioTranscriptionWordInfo
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1AudioTranscriptionWordInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Information about a single recognized word.
Instance Attribute Summary collapse
-
#end_offset ⇒ String
Optional.
-
#start_offset ⇒ String
Optional.
-
#word ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AudioTranscriptionWordInfo
constructor
A new instance of GoogleCloudAiplatformV1beta1AudioTranscriptionWordInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1AudioTranscriptionWordInfo
Returns a new instance of GoogleCloudAiplatformV1beta1AudioTranscriptionWordInfo.
288 289 290 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 288 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_offset ⇒ String
Optional. End offset in time of the word relative to the start of the audio.
Corresponds to the JSON property endOffset
276 277 278 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 276 def end_offset @end_offset end |
#start_offset ⇒ String
Optional. Start offset in time of the word relative to the start of the audio.
Corresponds to the JSON property startOffset
281 282 283 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 281 def start_offset @start_offset end |
#word ⇒ String
Required. Transcript of the word.
Corresponds to the JSON property word
286 287 288 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 286 def word @word end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
293 294 295 296 297 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 293 def update!(**args) @end_offset = args[:end_offset] if args.key?(:end_offset) @start_offset = args[:start_offset] if args.key?(:start_offset) @word = args[:word] if args.key?(:word) end |