Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Instance Attribute Summary collapse
-
#parts ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Part>
Required.
-
#role ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Content
constructor
A new instance of GoogleCloudAiplatformV1beta1Content.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Content
Returns a new instance of GoogleCloudAiplatformV1beta1Content.
565 566 567 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parts ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Part>
Required. A list of Part objects that make up a single message. Parts of a
message can have different MIME types. A Content message must have at least
one Part.
Corresponds to the JSON property parts
557 558 559 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 557 def parts @parts end |
#role ⇒ String
Optional. The producer of the content. Must be either 'user' or 'model'. If
not set, the service will default to 'user'.
Corresponds to the JSON property role
563 564 565 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 563 def role @role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
570 571 572 573 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 570 def update!(**args) @parts = args[:parts] if args.key?(:parts) @role = args[:role] if args.key?(:role) end |