Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1CountTokensRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1CountTokensRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Request message for PredictionService.CountTokens.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content>
Optional.
-
#generation_config ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation.
-
#instances ⇒ Array<Object>
Optional.
-
#model ⇒ String
Optional.
-
#system_instruction ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
-
#tools ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Tool>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CountTokensRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1CountTokensRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CountTokensRequest
Returns a new instance of GoogleCloudAiplatformV1beta1CountTokensRequest.
657 658 659 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content>
Optional. Input content.
Corresponds to the JSON property contents
621 622 623 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 621 def contents @contents end |
#generation_config ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property generationConfig
628 629 630 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 628 def generation_config @generation_config end |
#instances ⇒ Array<Object>
Optional. The instances that are the input to token counting call. Schema is
identical to the prediction schema of the underlying model.
Corresponds to the JSON property instances
634 635 636 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 634 def instances @instances end |
#model ⇒ String
Optional. The name of the publisher model requested to serve the prediction.
Format: projects/project/locations/location/publishers/*/models/*
Corresponds to the JSON property model
640 641 642 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 640 def model @model end |
#system_instruction ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property systemInstruction
647 648 649 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 647 def system_instruction @system_instruction end |
#tools ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Tool>
Optional. A list of Tools the model may use to generate the next response. A
Tool is a piece of code that enables the system to interact with external
systems to perform an action, or set of actions, outside of knowledge and
scope of the model.
Corresponds to the JSON property tools
655 656 657 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 655 def tools @tools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
662 663 664 665 666 667 668 669 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 662 def update!(**args) @contents = args[:contents] if args.key?(:contents) @generation_config = args[:generation_config] if args.key?(:generation_config) @instances = args[:instances] if args.key?(:instances) @model = args[:model] if args.key?(:model) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tools = args[:tools] if args.key?(:tools) end |