Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1CountTokensRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Request message for PredictionService.CountTokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1CountTokensRequest

Returns a new instance of GoogleCloudAiplatformV1beta1CountTokensRequest.



619
620
621
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content>

Optional. Input content. Corresponds to the JSON property contents



583
584
585
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 583

def contents
  @contents
end

#generation_configGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



590
591
592
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 590

def generation_config
  @generation_config
end

#instancesArray<Object>

Optional. The instances that are the input to token counting call. Schema is identical to the prediction schema of the underlying model. Corresponds to the JSON property instances

Returns:

  • (Array<Object>)


596
597
598
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 596

def instances
  @instances
end

#modelString

Optional. The name of the publisher model requested to serve the prediction. Format: projects/project/locations/location/publishers/*/models/* Corresponds to the JSON property model

Returns:

  • (String)


602
603
604
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 602

def model
  @model
end

#system_instructionGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property systemInstruction



609
610
611
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 609

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Tool>

Optional. A list of Tools the model may use to generate the next response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. Corresponds to the JSON property tools



617
618
619
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 617

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



624
625
626
627
628
629
630
631
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 624

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @instances = args[:instances] if args.key?(:instances)
  @model = args[:model] if args.key?(:model)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
end