Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExecutableCode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the CodeExecution tool, in which the code will be automatically executed, and a corresponding CodeExecutionResult will also be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode

Returns a new instance of GoogleCloudAiplatformV1beta1ExecutableCode.



775
776
777
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 775

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Required. The code to be executed. Corresponds to the JSON property code

Returns:

  • (String)


768
769
770
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 768

def code
  @code
end

#languageString

Required. Programming language of the code. Corresponds to the JSON property language

Returns:

  • (String)


773
774
775
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 773

def language
  @language
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



780
781
782
783
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 780

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @language = args[:language] if args.key?(:language)
end