Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExecutableCode
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExecutableCode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Code generated by the model that is meant to be executed, and the result
returned to the model. Generated when using the CodeExecution tool, in which
the code will be automatically executed, and a corresponding
CodeExecutionResult will also be generated.
Instance Attribute Summary collapse
-
#code ⇒ String
Required.
-
#language ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode
constructor
A new instance of GoogleCloudAiplatformV1beta1ExecutableCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExecutableCode
Returns a new instance of GoogleCloudAiplatformV1beta1ExecutableCode.
737 738 739 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Required. The code to be executed.
Corresponds to the JSON property code
730 731 732 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 730 def code @code end |
#language ⇒ String
Required. Programming language of the code.
Corresponds to the JSON property language
735 736 737 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 735 def language @language end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
742 743 744 745 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 742 def update!(**args) @code = args[:code] if args.key?(:code) @language = args[:language] if args.key?(:language) end |