Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExternalApi

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Retrieve from data source powered by external API for grounding. The external API is not owned by Google, but need to follow the pre-defined API spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ExternalApi

Returns a new instance of GoogleCloudAiplatformV1beta1ExternalApi.



787
788
789
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 787

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_authGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ApiAuth

The generic reusable api auth config. Deprecated. Please use AuthConfig ( google/cloud/aiplatform/master/auth.proto) instead. Corresponds to the JSON property apiAuth



758
759
760
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 758

def api_auth
  @api_auth
end

#api_specString

The API spec that the external API implements. Corresponds to the JSON property apiSpec

Returns:

  • (String)


763
764
765
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 763

def api_spec
  @api_spec
end

#auth_configGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1AuthConfig

Auth configuration to run the extension. Corresponds to the JSON property authConfig



768
769
770
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 768

def auth_config
  @auth_config
end

#elastic_search_paramsGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExternalApiElasticSearchParams

The search parameters to use for the ELASTIC_SEARCH spec. Corresponds to the JSON property elasticSearchParams



773
774
775
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 773

def elastic_search_params
  @elastic_search_params
end

#endpointString

The endpoint of the external API. The system will call the API at this endpoint to retrieve the data for grounding. Example: https://acme.com:443/ search Corresponds to the JSON property endpoint

Returns:

  • (String)


780
781
782
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 780

def endpoint
  @endpoint
end

#simple_search_paramsGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExternalApiSimpleSearchParams

The search parameters to use for SIMPLE_SEARCH spec. Corresponds to the JSON property simpleSearchParams



785
786
787
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 785

def simple_search_params
  @simple_search_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



792
793
794
795
796
797
798
799
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 792

def update!(**args)
  @api_auth = args[:api_auth] if args.key?(:api_auth)
  @api_spec = args[:api_spec] if args.key?(:api_spec)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @elastic_search_params = args[:elastic_search_params] if args.key?(:elastic_search_params)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @simple_search_params = args[:simple_search_params] if args.key?(:simple_search_params)
end