Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionCall
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionCall
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
A predicted [FunctionCall] returned from the model that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing the parameters and their values.
Instance Attribute Summary collapse
-
#args ⇒ Hash<String,Object>
Optional.
-
#id ⇒ String
Optional.
-
#name ⇒ String
Optional.
-
#partial_args ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1PartialArg>
Optional.
-
#will_continue ⇒ Boolean
(also: #will_continue?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionCall
constructor
A new instance of GoogleCloudAiplatformV1beta1FunctionCall.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionCall
Returns a new instance of GoogleCloudAiplatformV1beta1FunctionCall.
919 920 921 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Hash<String,Object>
Optional. The function parameters and values in JSON object format. See [
FunctionDeclaration.parameters] for parameter details.
Corresponds to the JSON property args
893 894 895 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 893 def args @args end |
#id ⇒ String
Optional. The unique id of the function call. If populated, the client to
execute the function_call and return the response with the matching id.
Corresponds to the JSON property id
899 900 901 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 899 def id @id end |
#name ⇒ String
Optional. The name of the function to call. Matches [FunctionDeclaration.name].
Corresponds to the JSON property name
904 905 906 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 904 def name @name end |
#partial_args ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1PartialArg>
Optional. The partial argument value of the function call. If provided,
represents the arguments/fields that are streamed incrementally.
Corresponds to the JSON property partialArgs
910 911 912 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 910 def partial_args @partial_args end |
#will_continue ⇒ Boolean Also known as: will_continue?
Optional. Whether this is the last part of the FunctionCall. If true, another
partial message for the current FunctionCall is expected to follow.
Corresponds to the JSON property willContinue
916 917 918 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 916 def will_continue @will_continue end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
924 925 926 927 928 929 930 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 924 def update!(**args) @args = args[:args] if args.key?(:args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @partial_args = args[:partial_args] if args.key?(:partial_args) @will_continue = args[:will_continue] if args.key?(:will_continue) end |