Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
The result output from a FunctionCall that contains a string representing the
FunctionDeclaration.name and a structured JSON object containing any output
from the function is used as context to the model. This should contain the
result of a FunctionCall made based on model prediction.
Instance Attribute Summary collapse
-
#id ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#parts ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionResponsePart>
Optional.
-
#response ⇒ Hash<String,Object>
Required.
-
#scheduling ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionResponse
constructor
A new instance of GoogleCloudAiplatformV1beta1FunctionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1FunctionResponse
Returns a new instance of GoogleCloudAiplatformV1beta1FunctionResponse.
1283 1284 1285 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Optional. The id of the function call this response is for. Populated by the
client to match the corresponding function call id.
Corresponds to the JSON property id
1254 1255 1256 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1254 def id @id end |
#name ⇒ String
Required. The name of the function to call. Matches FunctionDeclaration.name
and FunctionCall.name.
Corresponds to the JSON property name
1260 1261 1262 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1260 def name @name end |
#parts ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionResponsePart>
Optional. Ordered Parts that constitute a function response. Parts may have
different IANA MIME types.
Corresponds to the JSON property parts
1266 1267 1268 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1266 def parts @parts end |
#response ⇒ Hash<String,Object>
Required. The function response in JSON object format. Use "output" key to
specify function output and "error" key to specify error details (if any). If "
output" and "error" keys are not specified, then whole "response" is treated
as function output.
Corresponds to the JSON property response
1274 1275 1276 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1274 def response @response end |
#scheduling ⇒ String
Optional. Specifies how the response should be scheduled in the conversation.
Only applicable to NON_BLOCKING function calls, is ignored otherwise. Defaults
to WHEN_IDLE.
Corresponds to the JSON property scheduling
1281 1282 1283 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1281 def scheduling @scheduling end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1288 1289 1290 1291 1292 1293 1294 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1288 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @parts = args[:parts] if args.key?(:parts) @response = args[:response] if args.key?(:response) @scheduling = args[:scheduling] if args.key?(:scheduling) end |