Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerateContentRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerateContentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Request message for [PredictionService.GenerateContent].
Instance Attribute Summary collapse
-
#cached_content ⇒ String
Optional.
-
#contents ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content>
Required.
-
#generation_config ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation.
-
#labels ⇒ Hash<String,String>
Optional.
-
#model_armor_config ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ModelArmorConfig
Configuration for Model Armor.
-
#safety_settings ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1SafetySetting>
Optional.
-
#system_instruction ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content
The structured data content of a message.
-
#tool_config ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolConfig
Tool config.
-
#tools ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Tool>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateContentRequest
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerateContentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateContentRequest
Returns a new instance of GoogleCloudAiplatformV1beta1GenerateContentRequest.
1267 1268 1269 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cached_content ⇒ String
Optional. The name of the cached content used as context to serve the
prediction. Note: only used in explicit caching, where users can have control
over caching (e.g. what content to cache) and enjoy guaranteed cost savings.
Format: projects/project/locations/location/cachedContents/cachedContent
Corresponds to the JSON property cachedContent
1208 1209 1210 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1208 def cached_content @cached_content end |
#contents ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content>
Required. The content of the current conversation with the model. For single-
turn queries, this is a single instance. For multi-turn queries, this is a
repeated field that contains conversation history + latest request.
Corresponds to the JSON property contents
1215 1216 1217 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1215 def contents @contents end |
#generation_config ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property generationConfig
1222 1223 1224 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1222 def generation_config @generation_config end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata for the request. It is used
for billing and reporting only. Label keys and values can be no longer than 63
characters (Unicode codepoints) and can only contain lowercase letters,
numeric characters, underscores, and dashes. International characters are
allowed. Label values are optional. Label keys must start with a letter.
Corresponds to the JSON property labels
1231 1232 1233 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1231 def labels @labels end |
#model_armor_config ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ModelArmorConfig
Configuration for Model Armor. Model Armor is a Google Cloud service that
provides safety and security filtering for prompts and responses. It helps
protect your AI applications from risks such as harmful content, sensitive
data leakage, and prompt injection attacks.
Corresponds to the JSON property modelArmorConfig
1239 1240 1241 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1239 def model_armor_config @model_armor_config end |
#safety_settings ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1SafetySetting>
Optional. Per request settings for blocking unsafe content. Enforced on
GenerateContentResponse.candidates.
Corresponds to the JSON property safetySettings
1245 1246 1247 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1245 def safety_settings @safety_settings end |
#system_instruction ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property systemInstruction
1252 1253 1254 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1252 def system_instruction @system_instruction end |
#tool_config ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolConfig
Tool config. This config is shared for all tools provided in the request.
Corresponds to the JSON property toolConfig
1257 1258 1259 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1257 def tool_config @tool_config end |
#tools ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Tool>
Optional. A list of Tools the model may use to generate the next response. A
Tool is a piece of code that enables the system to interact with external
systems to perform an action, or set of actions, outside of knowledge and
scope of the model.
Corresponds to the JSON property tools
1265 1266 1267 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1265 def tools @tools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1272 def update!(**args) @cached_content = args[:cached_content] if args.key?(:cached_content) @contents = args[:contents] if args.key?(:contents) @generation_config = args[:generation_config] if args.key?(:generation_config) @labels = args[:labels] if args.key?(:labels) @model_armor_config = args[:model_armor_config] if args.key?(:model_armor_config) @safety_settings = args[:safety_settings] if args.key?(:safety_settings) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tool_config = args[:tool_config] if args.key?(:tool_config) @tools = args[:tools] if args.key?(:tools) end |