Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerateContentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Request message for [PredictionService.GenerateContent].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerateContentRequest

Returns a new instance of GoogleCloudAiplatformV1beta1GenerateContentRequest.



1252
1253
1254
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1252

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cached_contentString

Optional. The name of the cached content used as context to serve the prediction. Note: only used in explicit caching, where users can have control over caching (e.g. what content to cache) and enjoy guaranteed cost savings. Format: projects/project/locations/location/cachedContents/cachedContent Corresponds to the JSON property cachedContent

Returns:

  • (String)


1193
1194
1195
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1193

def cached_content
  @cached_content
end

#contentsArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content>

Required. The content of the current conversation with the model. For single- turn queries, this is a single instance. For multi-turn queries, this is a repeated field that contains conversation history + latest request. Corresponds to the JSON property contents



1200
1201
1202
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1200

def contents
  @contents
end

#generation_configGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



1207
1208
1209
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1207

def generation_config
  @generation_config
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata for the request. It is used for billing and reporting only. Label keys and values can be no longer than 63 characters (Unicode codepoints) and can only contain lowercase letters, numeric characters, underscores, and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1216
1217
1218
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1216

def labels
  @labels
end

#model_armor_configGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ModelArmorConfig

Configuration for Model Armor. Model Armor is a Google Cloud service that provides safety and security filtering for prompts and responses. It helps protect your AI applications from risks such as harmful content, sensitive data leakage, and prompt injection attacks. Corresponds to the JSON property modelArmorConfig



1224
1225
1226
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1224

def model_armor_config
  @model_armor_config
end

#safety_settingsArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1SafetySetting>

Optional. Per request settings for blocking unsafe content. Enforced on GenerateContentResponse.candidates. Corresponds to the JSON property safetySettings



1230
1231
1232
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1230

def safety_settings
  @safety_settings
end

#system_instructionGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property systemInstruction



1237
1238
1239
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1237

def system_instruction
  @system_instruction
end

#tool_configGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolConfig

Tool config. This config is shared for all tools provided in the request. Corresponds to the JSON property toolConfig



1242
1243
1244
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1242

def tool_config
  @tool_config
end

#toolsArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Tool>

Optional. A list of Tools the model may use to generate the next response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. Corresponds to the JSON property tools



1250
1251
1252
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1250

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1257

def update!(**args)
  @cached_content = args[:cached_content] if args.key?(:cached_content)
  @contents = args[:contents] if args.key?(:contents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @labels = args[:labels] if args.key?(:labels)
  @model_armor_config = args[:model_armor_config] if args.key?(:model_armor_config)
  @safety_settings = args[:safety_settings] if args.key?(:safety_settings)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tool_config = args[:tool_config] if args.key?(:tool_config)
  @tools = args[:tools] if args.key?(:tools)
end