Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
The configuration for automated routing. When automated routing is specified, the routing will be determined by the pretrained routing model and customer provided model routing preference.
Instance Attribute Summary collapse
-
#model_routing_preference ⇒ String
The model routing preference.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode
Returns a new instance of GoogleCloudAiplatformV1beta1GenerationConfigRoutingConfigAutoRoutingMode.
1727 1728 1729 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1727 def initialize(**args) update!(**args) end |
Instance Attribute Details
#model_routing_preference ⇒ String
The model routing preference.
Corresponds to the JSON property modelRoutingPreference
1725 1726 1727 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1725 def model_routing_preference @model_routing_preference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1732 1733 1734 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1732 def update!(**args) @model_routing_preference = args[:model_routing_preference] if args.key?(:model_routing_preference) end |