Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfigThinkingConfig
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GenerationConfigThinkingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Configuration for the model's thinking features. "Thinking" is a process where the model breaks down a complex task into smaller, manageable steps. This allows the model to reason about the task, plan its approach, and execute the plan to generate a high-quality response.
Instance Attribute Summary collapse
-
#include_thoughts ⇒ Boolean
(also: #include_thoughts?)
Optional.
-
#thinking_budget ⇒ Fixnum
Optional.
-
#thinking_level ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigThinkingConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1GenerationConfigThinkingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GenerationConfigThinkingConfig
Returns a new instance of GoogleCloudAiplatformV1beta1GenerationConfigThinkingConfig.
1847 1848 1849 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1847 def initialize(**args) update!(**args) end |
Instance Attribute Details
#include_thoughts ⇒ Boolean Also known as: include_thoughts?
Optional. If true, the model will include its thoughts in the response. "
Thoughts" are the intermediate steps the model takes to arrive at the final
response. They can provide insights into the model's reasoning process and
help with debugging. If this is true, thoughts are returned only when
available.
Corresponds to the JSON property includeThoughts
1832 1833 1834 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1832 def include_thoughts @include_thoughts end |
#thinking_budget ⇒ Fixnum
Optional. The token budget for the model's thinking process. The model will
make a best effort to stay within this budget. This can be used to control the
trade-off between response quality and latency.
Corresponds to the JSON property thinkingBudget
1840 1841 1842 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1840 def thinking_budget @thinking_budget end |
#thinking_level ⇒ String
Optional. The number of thoughts tokens that the model should generate.
Corresponds to the JSON property thinkingLevel
1845 1846 1847 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1845 def thinking_level @thinking_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1852 1853 1854 1855 1856 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1852 def update!(**args) @include_thoughts = args[:include_thoughts] if args.key?(:include_thoughts) @thinking_budget = args[:thinking_budget] if args.key?(:thinking_budget) @thinking_level = args[:thinking_level] if args.key?(:thinking_level) end |