Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GoogleMaps

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Tool to retrieve public maps data for grounding, powered by Google.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GoogleMaps

Returns a new instance of GoogleCloudAiplatformV1beta1GoogleMaps.



2048
2049
2050
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_widgetBoolean Also known as: enable_widget?

Optional. Deprecated: The Google Maps contextual widget behavior in Grounding with Google Maps is being deprecated; this field is planned for removal and no longer has any effect once removed. If true, include the widget context token in the response. Corresponds to the JSON property enableWidget

Returns:

  • (Boolean)


2039
2040
2041
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2039

def enable_widget
  @enable_widget
end

#grounding_typesGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GoogleMapsGroundingTypes

Defines the types of Google Maps grounding that can be enabled and their configurations. Corresponds to the JSON property groundingTypes



2046
2047
2048
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2046

def grounding_types
  @grounding_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2053
2054
2055
2056
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2053

def update!(**args)
  @enable_widget = args[:enable_widget] if args.key?(:enable_widget)
  @grounding_types = args[:grounding_types] if args.key?(:grounding_types)
end