Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

A piece of evidence that supports a claim made by the model. This is used to show a citation for a claim made by the model. When grounding is enabled, the model returns a GroundingChunk that contains a reference to the source of the information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunk

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunk.



1865
1866
1867
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mapsGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMaps

A Maps chunk is a piece of evidence that comes from Google Maps. It contains information about a place, such as its name, address, and reviews. This is used to provide the user with rich, location-based information. Corresponds to the JSON property maps



1849
1850
1851
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1849

def maps
  @maps
end

#retrieved_contextGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext

Context retrieved from a data source to ground the model's response. This is used when a retrieval tool fetches information from a user-provided corpus or a public dataset. Corresponds to the JSON property retrievedContext



1856
1857
1858
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1856

def retrieved_context
  @retrieved_context
end

#webGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkWeb

A Web chunk is a piece of evidence that comes from a web page. It contains the URI of the web page, the title of the page, and the domain of the page. This is used to provide the user with a link to the source of the information. Corresponds to the JSON property web



1863
1864
1865
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1863

def web
  @web
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1870
1871
1872
1873
1874
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1870

def update!(**args)
  @maps = args[:maps] if args.key?(:maps)
  @retrieved_context = args[:retrieved_context] if args.key?(:retrieved_context)
  @web = args[:web] if args.key?(:web)
end