Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

An Image chunk is a piece of evidence that comes from an image search result. It contains the URI of the image search result and the URI of the image. This is used to provide the user with a link to the source of the information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkImage

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkImage.



2206
2207
2208
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

The domain of the image search result page. Corresponds to the JSON property domain

Returns:

  • (String)


2189
2190
2191
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2189

def domain
  @domain
end

#image_uriString

The URI of the image. Corresponds to the JSON property imageUri

Returns:

  • (String)


2194
2195
2196
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2194

def image_uri
  @image_uri
end

#source_uriString

The URI of the image search result page. Corresponds to the JSON property sourceUri

Returns:

  • (String)


2199
2200
2201
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2199

def source_uri
  @source_uri
end

#titleString

The title of the image search result page. Corresponds to the JSON property title

Returns:

  • (String)


2204
2205
2206
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2204

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2211
2212
2213
2214
2215
2216
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2211

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @title = args[:title] if args.key?(:title)
end