Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

An Image chunk is a piece of evidence that comes from an image search result. It contains the URI of the image search result and the URI of the image. This is used to provide the user with a link to the source of the information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkImage

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkImage.



1975
1976
1977
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

The domain of the image search result page. Corresponds to the JSON property domain

Returns:

  • (String)


1958
1959
1960
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1958

def domain
  @domain
end

#image_uriString

The URI of the image. Corresponds to the JSON property imageUri

Returns:

  • (String)


1963
1964
1965
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1963

def image_uri
  @image_uri
end

#source_uriString

The URI of the image search result page. Corresponds to the JSON property sourceUri

Returns:

  • (String)


1968
1969
1970
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1968

def source_uri
  @source_uri
end

#titleString

The title of the image search result page. Corresponds to the JSON property title

Returns:

  • (String)


1973
1974
1975
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1973

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1980
1981
1982
1983
1984
1985
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1980

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @title = args[:title] if args.key?(:title)
end