Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

An Image chunk is a piece of evidence that comes from an image search result. It contains the URI of the image search result and the URI of the image. This is used to provide the user with a link to the source of the information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkImage

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkImage.



1928
1929
1930
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

The domain of the image search result page. Corresponds to the JSON property domain

Returns:

  • (String)


1911
1912
1913
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1911

def domain
  @domain
end

#image_uriString

The URI of the image. Corresponds to the JSON property imageUri

Returns:

  • (String)


1916
1917
1918
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1916

def image_uri
  @image_uri
end

#source_uriString

The URI of the image search result page. Corresponds to the JSON property sourceUri

Returns:

  • (String)


1921
1922
1923
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1921

def source_uri
  @source_uri
end

#titleString

The title of the image search result page. Corresponds to the JSON property title

Returns:

  • (String)


1926
1927
1928
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1926

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1933
1934
1935
1936
1937
1938
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1933

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @title = args[:title] if args.key?(:title)
end