Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMaps
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
A Maps chunk is a piece of evidence that comes from Google Maps, containing
information about places or routes. This is used to provide the user with rich,
location-based information.
Instance Attribute Summary collapse
-
#place_answer_sources ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer.
-
#place_id ⇒ String
This Place's resource name, in
places/place_id`` format. -
#route ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsRoute
Route information from Google Maps.
-
#text ⇒ String
The text of the place answer.
-
#title ⇒ String
The title of the place.
-
#uri ⇒ String
The URI of the place.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.
2271 2272 2273 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#place_answer_sources ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer. This includes review
snippets and photos that were used to generate the answer, as well as URIs to
flag content.
Corresponds to the JSON property placeAnswerSources
2243 2244 2245 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2243 def place_answer_sources @place_answer_sources end |
#place_id ⇒ String
This Place's resource name, in places/place_id`format. This can be used to
look up the place in the Google Maps API.
Corresponds to the JSON propertyplaceId`
2249 2250 2251 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2249 def place_id @place_id end |
#route ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsRoute
Route information from Google Maps.
Corresponds to the JSON property route
2254 2255 2256 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2254 def route @route end |
#text ⇒ String
The text of the place answer.
Corresponds to the JSON property text
2259 2260 2261 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2259 def text @text end |
#title ⇒ String
The title of the place.
Corresponds to the JSON property title
2264 2265 2266 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2264 def title @title end |
#uri ⇒ String
The URI of the place.
Corresponds to the JSON property uri
2269 2270 2271 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2269 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2276 2277 2278 2279 2280 2281 2282 2283 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2276 def update!(**args) @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources) @place_id = args[:place_id] if args.key?(:place_id) @route = args[:route] if args.key?(:route) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |