Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMaps
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
A Maps chunk is a piece of evidence that comes from Google Maps, containing
information about places or routes. This is used to provide the user with rich,
location-based information.
Instance Attribute Summary collapse
-
#place_answer_sources ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer.
-
#place_id ⇒ String
This Place's resource name, in
places/place_id`` format. -
#route ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsRoute
Route information from Google Maps.
-
#text ⇒ String
The text of the place answer.
-
#title ⇒ String
The title of the place.
-
#uri ⇒ String
The URI of the place.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.
2258 2259 2260 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2258 def initialize(**args) update!(**args) end |
Instance Attribute Details
#place_answer_sources ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer. This includes review
snippets and photos that were used to generate the answer, as well as URIs to
flag content.
Corresponds to the JSON property placeAnswerSources
2230 2231 2232 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2230 def place_answer_sources @place_answer_sources end |
#place_id ⇒ String
This Place's resource name, in places/place_id`format. This can be used to
look up the place in the Google Maps API.
Corresponds to the JSON propertyplaceId`
2236 2237 2238 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2236 def place_id @place_id end |
#route ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsRoute
Route information from Google Maps.
Corresponds to the JSON property route
2241 2242 2243 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2241 def route @route end |
#text ⇒ String
The text of the place answer.
Corresponds to the JSON property text
2246 2247 2248 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2246 def text @text end |
#title ⇒ String
The title of the place.
Corresponds to the JSON property title
2251 2252 2253 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2251 def title @title end |
#uri ⇒ String
The URI of the place.
Corresponds to the JSON property uri
2256 2257 2258 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2256 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2263 def update!(**args) @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources) @place_id = args[:place_id] if args.key?(:place_id) @route = args[:route] if args.key?(:route) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |