Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMaps

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

A Maps chunk is a piece of evidence that comes from Google Maps. It contains information about a place, such as its name, address, and reviews. This is used to provide the user with rich, location-based information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMaps

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMaps.



1911
1912
1913
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1911

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#place_answer_sourcesGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources

The sources that were used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content. Corresponds to the JSON property placeAnswerSources



1888
1889
1890
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1888

def place_answer_sources
  @place_answer_sources
end

#place_idString

This Place's resource name, in places/place_id`format. This can be used to look up the place in the Google Maps API. Corresponds to the JSON propertyplaceId`

Returns:

  • (String)


1894
1895
1896
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1894

def place_id
  @place_id
end

#textString

The text of the place answer. Corresponds to the JSON property text

Returns:

  • (String)


1899
1900
1901
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1899

def text
  @text
end

#titleString

The title of the place. Corresponds to the JSON property title

Returns:

  • (String)


1904
1905
1906
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1904

def title
  @title
end

#uriString

The URI of the place. Corresponds to the JSON property uri

Returns:

  • (String)


1909
1910
1911
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1909

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1916
1917
1918
1919
1920
1921
1922
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1916

def update!(**args)
  @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources)
  @place_id = args[:place_id] if args.key?(:place_id)
  @text = args[:text] if args.key?(:text)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end