Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
The sources that were used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content.
Instance Attribute Summary collapse
-
#review_snippets ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet>
Snippets of reviews that were used to generate the answer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources.
2297 2298 2299 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#review_snippets ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet>
Snippets of reviews that were used to generate the answer.
Corresponds to the JSON property reviewSnippets
2295 2296 2297 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2295 def review_snippets @review_snippets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2302 2303 2304 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2302 def update!(**args) @review_snippets = args[:review_snippets] if args.key?(:review_snippets) end |