Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

The sources that were used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSources.



2284
2285
2286
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#review_snippetsArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet>

Snippets of reviews that were used to generate the answer. Corresponds to the JSON property reviewSnippets



2282
2283
2284
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2282

def review_snippets
  @review_snippets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2289
2290
2291
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2289

def update!(**args)
  @review_snippets = args[:review_snippets] if args.key?(:review_snippets)
end