Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

A review snippet that is used to generate the answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.



1965
1966
1967
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_maps_uriString

A link to show the review on Google Maps. Corresponds to the JSON property googleMapsUri

Returns:

  • (String)


1953
1954
1955
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1953

def google_maps_uri
  @google_maps_uri
end

#review_idString

The ID of the review that is being referenced. Corresponds to the JSON property reviewId

Returns:

  • (String)


1958
1959
1960
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1958

def review_id
  @review_id
end

#titleString

The title of the review. Corresponds to the JSON property title

Returns:

  • (String)


1963
1964
1965
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1963

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1970
1971
1972
1973
1974
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1970

def update!(**args)
  @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri)
  @review_id = args[:review_id] if args.key?(:review_id)
  @title = args[:title] if args.key?(:title)
end