Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Context retrieved from a data source to ground the model's response. This is used when a retrieval tool fetches information from a user-provided corpus or a public dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingChunkRetrievedContext.



2012
2013
2014
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_nameString

Output only. The full resource name of the referenced Vertex AI Search document. This is used to identify the specific document that was retrieved. The format is projects/project/locations/location/collections/collection /dataStores/data_store/branches/branch/documents/document`. Corresponds to the JSON propertydocumentName`

Returns:

  • (String)


1989
1990
1991
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1989

def document_name
  @document_name
end

#rag_chunkGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunk

A RagChunk includes the content of a chunk of a RagFile, and associated metadata. Corresponds to the JSON property ragChunk



1995
1996
1997
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 1995

def rag_chunk
  @rag_chunk
end

#textString

The content of the retrieved data source. Corresponds to the JSON property text

Returns:

  • (String)


2000
2001
2002
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2000

def text
  @text
end

#titleString

The title of the retrieved data source. Corresponds to the JSON property title

Returns:

  • (String)


2005
2006
2007
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2005

def title
  @title
end

#uriString

The URI of the retrieved data source. Corresponds to the JSON property uri

Returns:

  • (String)


2010
2011
2012
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2010

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2017
2018
2019
2020
2021
2022
2023
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2017

def update!(**args)
  @document_name = args[:document_name] if args.key?(:document_name)
  @rag_chunk = args[:rag_chunk] if args.key?(:rag_chunk)
  @text = args[:text] if args.key?(:text)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end