Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingMetadata

Returns a new instance of GoogleCloudAiplatformV1beta1GroundingMetadata.



2279
2280
2281
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2279

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_maps_widget_context_tokenString

Optional. Output only. Deprecated: The Google Maps contextual widget behavior in Grounding with Google Maps is being deprecated; this field is planned for removal and will no longer be populated once removed. A token that can be used to render a Google Maps widget with the contextual data. This field is populated only when the grounding source is Google Maps. Corresponds to the JSON property googleMapsWidgetContextToken

Returns:

  • (String)


2222
2223
2224
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2222

def google_maps_widget_context_token
  @google_maps_widget_context_token
end

#grounding_chunksArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunk>

A list of supporting references retrieved from the grounding source. This field is populated when the grounding source is Google Search, Vertex AI Search, or Google Maps. Corresponds to the JSON property groundingChunks



2229
2230
2231
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2229

def grounding_chunks
  @grounding_chunks
end

#grounding_supportsArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingSupport>

Optional. A list of grounding supports that connect the generated content to the grounding chunks. This field is populated when the grounding source is Google Search or Vertex AI Search. Corresponds to the JSON property groundingSupports



2236
2237
2238
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2236

def grounding_supports
  @grounding_supports
end

#image_search_queriesArray<String>

Optional. The image search queries that were used to generate the content. This field is populated only when the grounding source is Google Search with the Image Search search_type enabled. Corresponds to the JSON property imageSearchQueries

Returns:

  • (Array<String>)


2243
2244
2245
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2243

def image_search_queries
  @image_search_queries
end

#retrieval_metadataGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RetrievalMetadata

Metadata related to the retrieval grounding source. This is part of the GroundingMetadata returned when grounding is enabled. Corresponds to the JSON property retrievalMetadata



2249
2250
2251
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2249

def 
  @retrieval_metadata
end

#retrieval_queriesArray<String>

Optional. The queries that were executed by the retrieval tools. This field is populated only when the grounding source is a retrieval tool, such as Vertex AI Search. Corresponds to the JSON property retrievalQueries

Returns:

  • (Array<String>)


2256
2257
2258
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2256

def retrieval_queries
  @retrieval_queries
end

#search_entry_pointGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1SearchEntryPoint

An entry point for displaying Google Search results. A SearchEntryPoint is populated when the grounding source for a model's response is Google Search. It provides information that you can use to display the search results in your application. Corresponds to the JSON property searchEntryPoint



2264
2265
2266
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2264

def search_entry_point
  @search_entry_point
end

#source_flagging_urisArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri>

Optional. Output only. A list of URIs that can be used to flag a place or review for inappropriate content. This field is populated only when the grounding source is Google Maps. Corresponds to the JSON property sourceFlaggingUris



2271
2272
2273
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2271

def source_flagging_uris
  @source_flagging_uris
end

#web_search_queriesArray<String>

Optional. The web search queries that were used to generate the content. This field is populated only when the grounding source is Google Search. Corresponds to the JSON property webSearchQueries

Returns:

  • (Array<String>)


2277
2278
2279
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2277

def web_search_queries
  @web_search_queries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2284

def update!(**args)
  @google_maps_widget_context_token = args[:google_maps_widget_context_token] if args.key?(:google_maps_widget_context_token)
  @grounding_chunks = args[:grounding_chunks] if args.key?(:grounding_chunks)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @image_search_queries = args[:image_search_queries] if args.key?(:image_search_queries)
  @retrieval_metadata = args[:retrieval_metadata] if args.key?(:retrieval_metadata)
  @retrieval_queries = args[:retrieval_queries] if args.key?(:retrieval_queries)
  @search_entry_point = args[:search_entry_point] if args.key?(:search_entry_point)
  @source_flagging_uris = args[:source_flagging_uris] if args.key?(:source_flagging_uris)
  @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries)
end