Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources.
Instance Attribute Summary collapse
-
#google_maps_widget_context_token ⇒ String
Optional.
-
#grounding_chunks ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunk>
A list of supporting references retrieved from the grounding source.
-
#grounding_supports ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingSupport>
Optional.
-
#retrieval_metadata ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RetrievalMetadata
Metadata related to the retrieval grounding source.
-
#retrieval_queries ⇒ Array<String>
Optional.
-
#search_entry_point ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1SearchEntryPoint
An entry point for displaying Google Search results.
-
#source_flagging_uris ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri>
Optional.
-
#web_search_queries ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingMetadata
constructor
A new instance of GoogleCloudAiplatformV1beta1GroundingMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1GroundingMetadata
Returns a new instance of GoogleCloudAiplatformV1beta1GroundingMetadata.
2121 2122 2123 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_maps_widget_context_token ⇒ String
Optional. Output only. A token that can be used to render a Google Maps widget
with the contextual data. This field is populated only when the grounding
source is Google Maps.
Corresponds to the JSON property googleMapsWidgetContextToken
2071 2072 2073 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2071 def @google_maps_widget_context_token end |
#grounding_chunks ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingChunk>
A list of supporting references retrieved from the grounding source. This
field is populated when the grounding source is Google Search, Vertex AI
Search, or Google Maps.
Corresponds to the JSON property groundingChunks
2078 2079 2080 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2078 def grounding_chunks @grounding_chunks end |
#grounding_supports ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingSupport>
Optional. A list of grounding supports that connect the generated content to
the grounding chunks. This field is populated when the grounding source is
Google Search or Vertex AI Search.
Corresponds to the JSON property groundingSupports
2085 2086 2087 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2085 def grounding_supports @grounding_supports end |
#retrieval_metadata ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RetrievalMetadata
Metadata related to the retrieval grounding source. This is part of the
GroundingMetadata returned when grounding is enabled.
Corresponds to the JSON property retrievalMetadata
2091 2092 2093 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2091 def @retrieval_metadata end |
#retrieval_queries ⇒ Array<String>
Optional. The queries that were executed by the retrieval tools. This field is
populated only when the grounding source is a retrieval tool, such as Vertex
AI Search.
Corresponds to the JSON property retrievalQueries
2098 2099 2100 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2098 def retrieval_queries @retrieval_queries end |
#search_entry_point ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1SearchEntryPoint
An entry point for displaying Google Search results. A SearchEntryPoint is
populated when the grounding source for a model's response is Google Search.
It provides information that you can use to display the search results in your
application.
Corresponds to the JSON property searchEntryPoint
2106 2107 2108 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2106 def search_entry_point @search_entry_point end |
#source_flagging_uris ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GroundingMetadataSourceFlaggingUri>
Optional. Output only. A list of URIs that can be used to flag a place or
review for inappropriate content. This field is populated only when the
grounding source is Google Maps.
Corresponds to the JSON property sourceFlaggingUris
2113 2114 2115 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2113 def source_flagging_uris @source_flagging_uris end |
#web_search_queries ⇒ Array<String>
Optional. The web search queries that were used to generate the content. This
field is populated only when the grounding source is Google Search.
Corresponds to the JSON property webSearchQueries
2119 2120 2121 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2119 def web_search_queries @web_search_queries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2126 def update!(**args) @google_maps_widget_context_token = args[:google_maps_widget_context_token] if args.key?(:google_maps_widget_context_token) @grounding_chunks = args[:grounding_chunks] if args.key?(:grounding_chunks) @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports) @retrieval_metadata = args[:retrieval_metadata] if args.key?(:retrieval_metadata) @retrieval_queries = args[:retrieval_queries] if args.key?(:retrieval_queries) @search_entry_point = args[:search_entry_point] if args.key?(:search_entry_point) @source_flagging_uris = args[:source_flagging_uris] if args.key?(:source_flagging_uris) @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries) end |