Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1LogprobsResultCandidate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

A single token and its associated log probability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LogprobsResultCandidate

Returns a new instance of GoogleCloudAiplatformV1beta1LogprobsResultCandidate.



2544
2545
2546
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#log_probabilityFloat

The log probability of this token. A higher value indicates that the model was more confident in this token. The log probability can be used to assess the relative likelihood of different tokens and to identify when the model is uncertain. Corresponds to the JSON property logProbability

Returns:

  • (Float)


2529
2530
2531
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2529

def log_probability
  @log_probability
end

#tokenString

The token's string representation. Corresponds to the JSON property token

Returns:

  • (String)


2534
2535
2536
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2534

def token
  @token
end

#token_idFixnum

The token's numerical ID. While the token field provides the string representation of the token, the token_id is the numerical representation that the model uses internally. This can be useful for developers who want to build custom logic based on the model's vocabulary. Corresponds to the JSON property tokenId

Returns:

  • (Fixnum)


2542
2543
2544
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2542

def token_id
  @token_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2549
2550
2551
2552
2553
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2549

def update!(**args)
  @log_probability = args[:log_probability] if args.key?(:log_probability)
  @token = args[:token] if args.key?(:token)
  @token_id = args[:token_id] if args.key?(:token_id)
end