Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

A list of the top candidate tokens and their log probabilities at each decoding step. This can be used to see what other tokens the model considered.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates

Returns a new instance of GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates.



2566
2567
2568
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidatesArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1LogprobsResultCandidate>

The list of candidate tokens, sorted by log probability in descending order. Corresponds to the JSON property candidates



2564
2565
2566
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2564

def candidates
  @candidates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2571
2572
2573
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2571

def update!(**args)
  @candidates = args[:candidates] if args.key?(:candidates)
end