Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

A list of the top candidate tokens and their log probabilities at each decoding step. This can be used to see what other tokens the model considered.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates

Returns a new instance of GoogleCloudAiplatformV1beta1LogprobsResultTopCandidates.



2482
2483
2484
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidatesArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1LogprobsResultCandidate>

The list of candidate tokens, sorted by log probability in descending order. Corresponds to the JSON property candidates



2480
2481
2482
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2480

def candidates
  @candidates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2487
2488
2489
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2487

def update!(**args)
  @candidates = args[:candidates] if args.key?(:candidates)
end