Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ModelArmorConfig
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ModelArmorConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Configuration for Model Armor. Model Armor is a Google Cloud service that provides safety and security filtering for prompts and responses. It helps protect your AI applications from risks such as harmful content, sensitive data leakage, and prompt injection attacks.
Instance Attribute Summary collapse
-
#prompt_template_name ⇒ String
Optional.
-
#response_template_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelArmorConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1ModelArmorConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ModelArmorConfig
Returns a new instance of GoogleCloudAiplatformV1beta1ModelArmorConfig.
2418 2419 2420 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2418 def initialize(**args) update!(**args) end |
Instance Attribute Details
#prompt_template_name ⇒ String
Optional. The resource name of the Model Armor template to use for prompt
screening. A Model Armor template is a set of customized filters and
thresholds that define how Model Armor screens content. If specified, Model
Armor will use this template to check the user's prompt for safety and
security risks before it is sent to the model. The name must be in the format
projects/project/locations/location/templates/template`.
Corresponds to the JSON propertypromptTemplateName`
2406 2407 2408 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2406 def prompt_template_name @prompt_template_name end |
#response_template_name ⇒ String
Optional. The resource name of the Model Armor template to use for response
screening. A Model Armor template is a set of customized filters and
thresholds that define how Model Armor screens content. If specified, Model
Armor will use this template to check the model's response for safety and
security risks before it is returned to the user. The name must be in the
format projects/project/locations/location/templates/template`.
Corresponds to the JSON propertyresponseTemplateName`
2416 2417 2418 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2416 def response_template_name @response_template_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2423 2424 2425 2426 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2423 def update!(**args) @prompt_template_name = args[:prompt_template_name] if args.key?(:prompt_template_name) @response_template_name = args[:response_template_name] if args.key?(:response_template_name) end |