Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Part
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Part
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
A datatype containing media that is part of a multi-part Content message. A
Part consists of data which has an associated datatype. A Part can only
contain one of the accepted types in Part.data. For media types that are not
text, Part must have a fixed IANA MIME type identifying the type and subtype
of the media if inline_data or file_data field is filled with raw bytes.
Instance Attribute Summary collapse
-
#code_execution_result ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1CodeExecutionResult
Result of executing the ExecutableCode.
-
#executable_code ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExecutableCode
Code generated by the model that is meant to be executed, and the result returned to the model.
-
#file_data ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FileData
URI-based data.
-
#function_call ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionCall
A predicted FunctionCall returned from the model that contains a string representing the FunctionDeclaration.name and a structured JSON object containing the parameters and their values.
-
#function_response ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionResponse
The result output from a FunctionCall that contains a string representing the FunctionDeclaration.name and a structured JSON object containing any output from the function is used as context to the model.
-
#inline_data ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Blob
A content blob.
-
#media_resolution ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1PartMediaResolution
per part media resolution.
-
#text ⇒ String
Optional.
-
#thought ⇒ Boolean
(also: #thought?)
Optional.
-
#thought_signature ⇒ String
Optional.
-
#video_metadata ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VideoMetadata
Provides metadata for a video, including the start and end offsets for clipping and the frame rate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Part
constructor
A new instance of GoogleCloudAiplatformV1beta1Part.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Part
Returns a new instance of GoogleCloudAiplatformV1beta1Part.
2747 2748 2749 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_result ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1CodeExecutionResult
Result of executing the ExecutableCode. Generated only when the CodeExecution
tool is used.
Corresponds to the JSON property codeExecutionResult
2676 2677 2678 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2676 def code_execution_result @code_execution_result end |
#executable_code ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExecutableCode
Code generated by the model that is meant to be executed, and the result
returned to the model. Generated when using the CodeExecution tool, in which
the code will be automatically executed, and a corresponding
CodeExecutionResult will also be generated.
Corresponds to the JSON property executableCode
2684 2685 2686 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2684 def executable_code @executable_code end |
#file_data ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FileData
URI-based data. A FileData message contains a URI pointing to data of a
specific media type. It is used to represent images, audio, and video stored
in Google Cloud Storage.
Corresponds to the JSON property fileData
2691 2692 2693 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2691 def file_data @file_data end |
#function_call ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionCall
A predicted FunctionCall returned from the model that contains a string
representing the FunctionDeclaration.name and a structured JSON object
containing the parameters and their values.
Corresponds to the JSON property functionCall
2698 2699 2700 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2698 def function_call @function_call end |
#function_response ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionResponse
The result output from a FunctionCall that contains a string representing the
FunctionDeclaration.name and a structured JSON object containing any output
from the function is used as context to the model. This should contain the
result of a FunctionCall made based on model prediction.
Corresponds to the JSON property functionResponse
2706 2707 2708 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2706 def function_response @function_response end |
#inline_data ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Blob
A content blob. A Blob contains data of a specific media type. It is used to
represent images, audio, and video.
Corresponds to the JSON property inlineData
2712 2713 2714 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2712 def inline_data @inline_data end |
#media_resolution ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1PartMediaResolution
per part media resolution. Media resolution for the input media.
Corresponds to the JSON property mediaResolution
2717 2718 2719 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2717 def media_resolution @media_resolution end |
#text ⇒ String
Optional. The text content of the part. When sent from the VSCode Gemini Code
Assist extension, references to @mentioned items will be converted to markdown
boldface text. For example @my-repo will be converted to and sent as **my-
repo** by the IDE agent.
Corresponds to the JSON property text
2725 2726 2727 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2725 def text @text end |
#thought ⇒ Boolean Also known as: thought?
Optional. Indicates whether the part represents the model's thought process
or reasoning.
Corresponds to the JSON property thought
2731 2732 2733 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2731 def thought @thought end |
#thought_signature ⇒ String
Optional. An opaque signature for the thought so it can be reused in
subsequent requests.
Corresponds to the JSON property thoughtSignature
NOTE: Values are automatically base64 encoded/decoded in the client library.
2739 2740 2741 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2739 def thought_signature @thought_signature end |
#video_metadata ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VideoMetadata
Provides metadata for a video, including the start and end offsets for
clipping and the frame rate.
Corresponds to the JSON property videoMetadata
2745 2746 2747 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2745 def @video_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2752 2753 2754 2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2752 def update!(**args) @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result) @executable_code = args[:executable_code] if args.key?(:executable_code) @file_data = args[:file_data] if args.key?(:file_data) @function_call = args[:function_call] if args.key?(:function_call) @function_response = args[:function_response] if args.key?(:function_response) @inline_data = args[:inline_data] if args.key?(:inline_data) @media_resolution = args[:media_resolution] if args.key?(:media_resolution) @text = args[:text] if args.key?(:text) @thought = args[:thought] if args.key?(:thought) @thought_signature = args[:thought_signature] if args.key?(:thought_signature) @video_metadata = args[:video_metadata] if args.key?(:video_metadata) end |