Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Part
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Part
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
A datatype containing media that is part of a multi-part Content message. A
Part consists of data which has an associated datatype. A Part can only
contain one of the accepted types in Part.data. For media types that are not
text, Part must have a fixed IANA MIME type identifying the type and subtype
of the media if inline_data or file_data field is filled with raw bytes.
Instance Attribute Summary collapse
-
#code_execution_result ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1CodeExecutionResult
Result of executing the [ExecutableCode].
-
#executable_code ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExecutableCode
Code generated by the model that is meant to be executed, and the result returned to the model.
-
#file_data ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FileData
URI-based data.
-
#function_call ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionCall
A predicted [FunctionCall] returned from the model that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing the parameters and their values.
-
#function_response ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionResponse
The result output from a [FunctionCall] that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing any output from the function is used as context to the model.
-
#inline_data ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Blob
A content blob.
-
#media_resolution ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1PartMediaResolution
per part media resolution.
-
#text ⇒ String
Optional.
-
#thought ⇒ Boolean
(also: #thought?)
Optional.
-
#thought_signature ⇒ String
Optional.
-
#video_metadata ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VideoMetadata
Provides metadata for a video, including the start and end offsets for clipping and the frame rate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Part
constructor
A new instance of GoogleCloudAiplatformV1beta1Part.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Part
Returns a new instance of GoogleCloudAiplatformV1beta1Part.
2530 2531 2532 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_result ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1CodeExecutionResult
Result of executing the [ExecutableCode]. Only generated when using the [
CodeExecution] tool, and always follows a part containing the [
ExecutableCode].
Corresponds to the JSON property codeExecutionResult
2462 2463 2464 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2462 def code_execution_result @code_execution_result end |
#executable_code ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ExecutableCode
Code generated by the model that is meant to be executed, and the result
returned to the model. Generated when using the [CodeExecution] tool, in which
the code will be automatically executed, and a corresponding [
CodeExecutionResult] will also be generated.
Corresponds to the JSON property executableCode
2470 2471 2472 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2470 def executable_code @executable_code end |
#file_data ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FileData
URI-based data. A FileData message contains a URI pointing to data of a
specific media type. It is used to represent images, audio, and video stored
in Google Cloud Storage.
Corresponds to the JSON property fileData
2477 2478 2479 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2477 def file_data @file_data end |
#function_call ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionCall
A predicted [FunctionCall] returned from the model that contains a string
representing the [FunctionDeclaration.name] and a structured JSON object
containing the parameters and their values.
Corresponds to the JSON property functionCall
2484 2485 2486 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2484 def function_call @function_call end |
#function_response ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionResponse
The result output from a [FunctionCall] that contains a string representing
the [FunctionDeclaration.name] and a structured JSON object containing any
output from the function is used as context to the model. This should contain
the result of a [FunctionCall] made based on model prediction.
Corresponds to the JSON property functionResponse
2492 2493 2494 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2492 def function_response @function_response end |
#inline_data ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Blob
A content blob. A Blob contains data of a specific media type. It is used to
represent images, audio, and video.
Corresponds to the JSON property inlineData
2498 2499 2500 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2498 def inline_data @inline_data end |
#media_resolution ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1PartMediaResolution
per part media resolution. Media resolution for the input media.
Corresponds to the JSON property mediaResolution
2503 2504 2505 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2503 def media_resolution @media_resolution end |
#text ⇒ String
Optional. The text content of the part.
Corresponds to the JSON property text
2508 2509 2510 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2508 def text @text end |
#thought ⇒ Boolean Also known as: thought?
Optional. Indicates whether the part represents the model's thought process
or reasoning.
Corresponds to the JSON property thought
2514 2515 2516 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2514 def thought @thought end |
#thought_signature ⇒ String
Optional. An opaque signature for the thought so it can be reused in
subsequent requests.
Corresponds to the JSON property thoughtSignature
NOTE: Values are automatically base64 encoded/decoded in the client library.
2522 2523 2524 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2522 def thought_signature @thought_signature end |
#video_metadata ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VideoMetadata
Provides metadata for a video, including the start and end offsets for
clipping and the frame rate.
Corresponds to the JSON property videoMetadata
2528 2529 2530 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2528 def @video_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2535 def update!(**args) @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result) @executable_code = args[:executable_code] if args.key?(:executable_code) @file_data = args[:file_data] if args.key?(:file_data) @function_call = args[:function_call] if args.key?(:function_call) @function_response = args[:function_response] if args.key?(:function_response) @inline_data = args[:inline_data] if args.key?(:inline_data) @media_resolution = args[:media_resolution] if args.key?(:media_resolution) @text = args[:text] if args.key?(:text) @thought = args[:thought] if args.key?(:thought) @thought_signature = args[:thought_signature] if args.key?(:thought_signature) @video_metadata = args[:video_metadata] if args.key?(:video_metadata) end |