Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunk
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
Instance Attribute Summary collapse
-
#chunk_id ⇒ String
The ID of the chunk.
-
#file_id ⇒ String
The ID of the file that the chunk belongs to.
-
#page_span ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunkPageSpan
Represents where the chunk starts and ends in the document.
-
#text ⇒ String
The content of the chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagChunk
constructor
A new instance of GoogleCloudAiplatformV1beta1RagChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagChunk
Returns a new instance of GoogleCloudAiplatformV1beta1RagChunk.
2883 2884 2885 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_id ⇒ String
The ID of the chunk.
Corresponds to the JSON property chunkId
2866 2867 2868 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2866 def chunk_id @chunk_id end |
#file_id ⇒ String
The ID of the file that the chunk belongs to.
Corresponds to the JSON property fileId
2871 2872 2873 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2871 def file_id @file_id end |
#page_span ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunkPageSpan
Represents where the chunk starts and ends in the document.
Corresponds to the JSON property pageSpan
2876 2877 2878 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2876 def page_span @page_span end |
#text ⇒ String
The content of the chunk.
Corresponds to the JSON property text
2881 2882 2883 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2881 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2888 2889 2890 2891 2892 2893 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2888 def update!(**args) @chunk_id = args[:chunk_id] if args.key?(:chunk_id) @file_id = args[:file_id] if args.key?(:file_id) @page_span = args[:page_span] if args.key?(:page_span) @text = args[:text] if args.key?(:text) end |