Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunk
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
Instance Attribute Summary collapse
-
#chunk_id ⇒ String
The ID of the chunk.
-
#file_id ⇒ String
The ID of the file that the chunk belongs to.
-
#page_span ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunkPageSpan
Represents where the chunk starts and ends in the document.
-
#text ⇒ String
The content of the chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagChunk
constructor
A new instance of GoogleCloudAiplatformV1beta1RagChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagChunk
Returns a new instance of GoogleCloudAiplatformV1beta1RagChunk.
2799 2800 2801 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_id ⇒ String
The ID of the chunk.
Corresponds to the JSON property chunkId
2782 2783 2784 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2782 def chunk_id @chunk_id end |
#file_id ⇒ String
The ID of the file that the chunk belongs to.
Corresponds to the JSON property fileId
2787 2788 2789 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2787 def file_id @file_id end |
#page_span ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunkPageSpan
Represents where the chunk starts and ends in the document.
Corresponds to the JSON property pageSpan
2792 2793 2794 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2792 def page_span @page_span end |
#text ⇒ String
The content of the chunk.
Corresponds to the JSON property text
2797 2798 2799 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2797 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2804 2805 2806 2807 2808 2809 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2804 def update!(**args) @chunk_id = args[:chunk_id] if args.key?(:chunk_id) @file_id = args[:file_id] if args.key?(:file_id) @page_span = args[:page_span] if args.key?(:page_span) @text = args[:text] if args.key?(:text) end |