Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunk

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

A RagChunk includes the content of a chunk of a RagFile, and associated metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RagChunk

Returns a new instance of GoogleCloudAiplatformV1beta1RagChunk.



2656
2657
2658
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2656

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_spanGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RagChunkPageSpan

Represents where the chunk starts and ends in the document. Corresponds to the JSON property pageSpan



2649
2650
2651
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2649

def page_span
  @page_span
end

#textString

The content of the chunk. Corresponds to the JSON property text

Returns:

  • (String)


2654
2655
2656
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2654

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2661
2662
2663
2664
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2661

def update!(**args)
  @page_span = args[:page_span] if args.key?(:page_span)
  @text = args[:text] if args.key?(:text)
end