Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RetrievalConfig
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RetrievalConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Retrieval config.
Instance Attribute Summary collapse
-
#language_code ⇒ String
The language code of the user.
-
#lat_lng ⇒ Google::Apis::FirebasemlV2beta::LatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrievalConfig
constructor
A new instance of GoogleCloudAiplatformV1beta1RetrievalConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrievalConfig
Returns a new instance of GoogleCloudAiplatformV1beta1RetrievalConfig.
3454 3455 3456 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3454 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_code ⇒ String
The language code of the user.
Corresponds to the JSON property languageCode
3444 3445 3446 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3444 def language_code @language_code end |
#lat_lng ⇒ Google::Apis::FirebasemlV2beta::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property latLng
3452 3453 3454 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3452 def lat_lng @lat_lng end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3459 3460 3461 3462 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3459 def update!(**args) @language_code = args[:language_code] if args.key?(:language_code) @lat_lng = args[:lat_lng] if args.key?(:lat_lng) end |