Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RetrievalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Retrieval config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrievalConfig

Returns a new instance of GoogleCloudAiplatformV1beta1RetrievalConfig.



3441
3442
3443
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#language_codeString

The language code of the user. Corresponds to the JSON property languageCode

Returns:

  • (String)


3431
3432
3433
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3431

def language_code
  @language_code
end

#lat_lngGoogle::Apis::FirebasemlV2beta::LatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property latLng



3439
3440
3441
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3439

def lat_lng
  @lat_lng
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3446
3447
3448
3449
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3446

def update!(**args)
  @language_code = args[:language_code] if args.key?(:language_code)
  @lat_lng = args[:lat_lng] if args.key?(:lat_lng)
end