Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1RetrievalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Retrieval config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1RetrievalConfig

Returns a new instance of GoogleCloudAiplatformV1beta1RetrievalConfig.



2936
2937
2938
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#language_codeString

The language code of the user. Corresponds to the JSON property languageCode

Returns:

  • (String)


2926
2927
2928
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2926

def language_code
  @language_code
end

#lat_lngGoogle::Apis::FirebasemlV2beta::LatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property latLng



2934
2935
2936
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2934

def lat_lng
  @lat_lng
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2941
2942
2943
2944
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2941

def update!(**args)
  @language_code = args[:language_code] if args.key?(:language_code)
  @lat_lng = args[:lat_lng] if args.key?(:lat_lng)
end