Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1SafetyRating

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

A safety rating for a piece of content. The safety rating contains the harm category and the harm probability level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SafetyRating

Returns a new instance of GoogleCloudAiplatformV1beta1SafetyRating.



3281
3282
3283
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockedBoolean Also known as: blocked?

Output only. Indicates whether the content was blocked because of this rating. Corresponds to the JSON property blocked

Returns:

  • (Boolean)


3246
3247
3248
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3246

def blocked
  @blocked
end

#categoryString

Output only. The harm category of this rating. Corresponds to the JSON property category

Returns:

  • (String)


3252
3253
3254
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3252

def category
  @category
end

#overwritten_thresholdString

Output only. The overwritten threshold for the safety category of Gemini 2.0 image out. If minors are detected in the output image, the threshold of each safety category will be overwritten if user sets a lower threshold. Corresponds to the JSON property overwrittenThreshold

Returns:

  • (String)


3259
3260
3261
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3259

def overwritten_threshold
  @overwritten_threshold
end

#probabilityString

Output only. The probability of harm for this category. Corresponds to the JSON property probability

Returns:

  • (String)


3264
3265
3266
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3264

def probability
  @probability
end

#probability_scoreFloat

Output only. The probability score of harm for this category. Corresponds to the JSON property probabilityScore

Returns:

  • (Float)


3269
3270
3271
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3269

def probability_score
  @probability_score
end

#severityString

Output only. The severity of harm for this category. Corresponds to the JSON property severity

Returns:

  • (String)


3274
3275
3276
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3274

def severity
  @severity
end

#severity_scoreFloat

Output only. The severity score of harm for this category. Corresponds to the JSON property severityScore

Returns:

  • (Float)


3279
3280
3281
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3279

def severity_score
  @severity_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3286
3287
3288
3289
3290
3291
3292
3293
3294
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3286

def update!(**args)
  @blocked = args[:blocked] if args.key?(:blocked)
  @category = args[:category] if args.key?(:category)
  @overwritten_threshold = args[:overwritten_threshold] if args.key?(:overwritten_threshold)
  @probability = args[:probability] if args.key?(:probability)
  @probability_score = args[:probability_score] if args.key?(:probability_score)
  @severity = args[:severity] if args.key?(:severity)
  @severity_score = args[:severity_score] if args.key?(:severity_score)
end