Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1SafetyRating
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1SafetyRating
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
A safety rating for a piece of content. The safety rating contains the harm category and the harm probability level.
Instance Attribute Summary collapse
-
#blocked ⇒ Boolean
(also: #blocked?)
Output only.
-
#category ⇒ String
Output only.
-
#overwritten_threshold ⇒ String
Output only.
-
#probability ⇒ String
Output only.
-
#probability_score ⇒ Float
Output only.
-
#severity ⇒ String
Output only.
-
#severity_score ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SafetyRating
constructor
A new instance of GoogleCloudAiplatformV1beta1SafetyRating.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1SafetyRating
Returns a new instance of GoogleCloudAiplatformV1beta1SafetyRating.
3015 3016 3017 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocked ⇒ Boolean Also known as: blocked?
Output only. Indicates whether the content was blocked because of this rating.
Corresponds to the JSON property blocked
2980 2981 2982 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2980 def blocked @blocked end |
#category ⇒ String
Output only. The harm category of this rating.
Corresponds to the JSON property category
2986 2987 2988 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2986 def category @category end |
#overwritten_threshold ⇒ String
Output only. The overwritten threshold for the safety category of Gemini 2.0
image out. If minors are detected in the output image, the threshold of each
safety category will be overwritten if user sets a lower threshold.
Corresponds to the JSON property overwrittenThreshold
2993 2994 2995 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2993 def overwritten_threshold @overwritten_threshold end |
#probability ⇒ String
Output only. The probability of harm for this category.
Corresponds to the JSON property probability
2998 2999 3000 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 2998 def probability @probability end |
#probability_score ⇒ Float
Output only. The probability score of harm for this category.
Corresponds to the JSON property probabilityScore
3003 3004 3005 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3003 def probability_score @probability_score end |
#severity ⇒ String
Output only. The severity of harm for this category.
Corresponds to the JSON property severity
3008 3009 3010 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3008 def severity @severity end |
#severity_score ⇒ Float
Output only. The severity score of harm for this category.
Corresponds to the JSON property severityScore
3013 3014 3015 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3013 def severity_score @severity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3020 3021 3022 3023 3024 3025 3026 3027 3028 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3020 def update!(**args) @blocked = args[:blocked] if args.key?(:blocked) @category = args[:category] if args.key?(:category) @overwritten_threshold = args[:overwritten_threshold] if args.key?(:overwritten_threshold) @probability = args[:probability] if args.key?(:probability) @probability_score = args[:probability_score] if args.key?(:probability_score) @severity = args[:severity] if args.key?(:severity) @severity_score = args[:severity_score] if args.key?(:severity_score) end |