Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Schema

Returns a new instance of GoogleCloudAiplatformV1beta1Schema.



3498
3499
3500
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3498

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_propertiesObject

Optional. If type is OBJECT, specifies how to handle properties not defined in properties. If it is a boolean false, no additional properties are allowed. If it is a schema, additional properties are allowed if they conform to the schema. Corresponds to the JSON property additionalProperties

Returns:

  • (Object)


3342
3343
3344
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3342

def additional_properties
  @additional_properties
end

#any_ofArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema>

Optional. The instance must be valid against any (one or more) of the subschemas listed in any_of. Corresponds to the JSON property anyOf



3348
3349
3350
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3348

def any_of
  @any_of
end

#defaultObject

Optional. Default value to use if the field is not specified. Corresponds to the JSON property default

Returns:

  • (Object)


3353
3354
3355
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3353

def default
  @default
end

#defsHash<String,Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema>

Optional. defs provides a map of schema definitions that can be reused by ref elsewhere in the schema. Only allowed at root level of the schema. Corresponds to the JSON property defs



3359
3360
3361
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3359

def defs
  @defs
end

#descriptionString

Optional. Describes the data. The model uses this field to understand the purpose of the schema and how to use it. It is a best practice to provide a clear and descriptive explanation for the schema and its properties here, rather than in the prompt. Corresponds to the JSON property description

Returns:

  • (String)


3367
3368
3369
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3367

def description
  @description
end

#enumArray<String>

Optional. Possible values of the field. This field can be used to restrict a value to a fixed set of values. To mark a field as an enum, set format to enum and provide the list of possible values in enum. For example: 1. To define directions: type:STRING, format:enum, enum:["EAST", "NORTH", "SOUTH", "WEST"] 2. To define apartment numbers: type:INTEGER, format:enum, enum:[" 101", "201", "301"] Corresponds to the JSON property enum

Returns:

  • (Array<String>)


3377
3378
3379
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3377

def enum
  @enum
end

#exampleObject

Optional. Example of an instance of this schema. Corresponds to the JSON property example

Returns:

  • (Object)


3382
3383
3384
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3382

def example
  @example
end

#formatString

Optional. The format of the data. For NUMBER type, format can be float or double. For INTEGER type, format can be int32 or int64. For STRING type, format can be email, byte, date, date-time, password, and other formats to further refine the data type. Corresponds to the JSON property format

Returns:

  • (String)


3390
3391
3392
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3390

def format
  @format
end

#itemsGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object. Corresponds to the JSON property items



3396
3397
3398
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3396

def items
  @items
end

#max_itemsFixnum

Optional. If type is ARRAY, max_items specifies the maximum number of items in an array. Corresponds to the JSON property maxItems

Returns:

  • (Fixnum)


3402
3403
3404
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3402

def max_items
  @max_items
end

#max_lengthFixnum

Optional. If type is STRING, max_length specifies the maximum length of the string. Corresponds to the JSON property maxLength

Returns:

  • (Fixnum)


3408
3409
3410
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3408

def max_length
  @max_length
end

#max_propertiesFixnum

Optional. If type is OBJECT, max_properties specifies the maximum number of properties that can be provided. Corresponds to the JSON property maxProperties

Returns:

  • (Fixnum)


3414
3415
3416
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3414

def max_properties
  @max_properties
end

#maximumFloat

Optional. If type is INTEGER or NUMBER, maximum specifies the maximum allowed value. Corresponds to the JSON property maximum

Returns:

  • (Float)


3420
3421
3422
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3420

def maximum
  @maximum
end

#min_itemsFixnum

Optional. If type is ARRAY, min_items specifies the minimum number of items in an array. Corresponds to the JSON property minItems

Returns:

  • (Fixnum)


3426
3427
3428
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3426

def min_items
  @min_items
end

#min_lengthFixnum

Optional. If type is STRING, min_length specifies the minimum length of the string. Corresponds to the JSON property minLength

Returns:

  • (Fixnum)


3432
3433
3434
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3432

def min_length
  @min_length
end

#min_propertiesFixnum

Optional. If type is OBJECT, min_properties specifies the minimum number of properties that can be provided. Corresponds to the JSON property minProperties

Returns:

  • (Fixnum)


3438
3439
3440
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3438

def min_properties
  @min_properties
end

#minimumFloat

Optional. If type is INTEGER or NUMBER, minimum specifies the minimum allowed value. Corresponds to the JSON property minimum

Returns:

  • (Float)


3444
3445
3446
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3444

def minimum
  @minimum
end

#nullableBoolean Also known as: nullable?

Optional. Indicates if the value of this field can be null. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


3449
3450
3451
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3449

def nullable
  @nullable
end

#patternString

Optional. If type is STRING, pattern specifies a regular expression that the string must match. Corresponds to the JSON property pattern

Returns:

  • (String)


3456
3457
3458
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3456

def pattern
  @pattern
end

#propertiesHash<String,Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema>

Optional. If type is OBJECT, properties is a map of property names to schema definitions for each property of the object. Corresponds to the JSON property properties



3462
3463
3464
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3462

def properties
  @properties
end

#property_orderingArray<String>

Optional. Order of properties displayed or used where order matters. This is not a standard field in OpenAPI specification, but can be used to control the order of properties. Corresponds to the JSON property propertyOrdering

Returns:

  • (Array<String>)


3469
3470
3471
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3469

def property_ordering
  @property_ordering
end

#refString

Optional. Allows referencing another schema definition to use in place of this schema. The value must be a valid reference to a schema in defs. For example, the following schema defines a reference to a schema node named "Pet": type: object properties: pet: ref: #/defs/Pet defs: Pet: type: object properties: name: type: string The value of the "pet" property is a reference to the schema node named "Pet". See details in https://json-schema.org/understanding- json-schema/structuring Corresponds to the JSON property ref

Returns:

  • (String)


3480
3481
3482
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3480

def ref
  @ref
end

#requiredArray<String>

Optional. If type is OBJECT, required lists the names of properties that must be present. Corresponds to the JSON property required

Returns:

  • (Array<String>)


3486
3487
3488
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3486

def required
  @required
end

#titleString

Optional. Title for the schema. Corresponds to the JSON property title

Returns:

  • (String)


3491
3492
3493
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3491

def title
  @title
end

#typeString

Optional. Data type of the schema field. Corresponds to the JSON property type

Returns:

  • (String)


3496
3497
3498
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3496

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3503
3504
3505
3506
3507
3508
3509
3510
3511
3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
3527
3528
3529
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3503

def update!(**args)
  @additional_properties = args[:additional_properties] if args.key?(:additional_properties)
  @any_of = args[:any_of] if args.key?(:any_of)
  @default = args[:default] if args.key?(:default)
  @defs = args[:defs] if args.key?(:defs)
  @description = args[:description] if args.key?(:description)
  @enum = args[:enum] if args.key?(:enum)
  @example = args[:example] if args.key?(:example)
  @format = args[:format] if args.key?(:format)
  @items = args[:items] if args.key?(:items)
  @max_items = args[:max_items] if args.key?(:max_items)
  @max_length = args[:max_length] if args.key?(:max_length)
  @max_properties = args[:max_properties] if args.key?(:max_properties)
  @maximum = args[:maximum] if args.key?(:maximum)
  @min_items = args[:min_items] if args.key?(:min_items)
  @min_length = args[:min_length] if args.key?(:min_length)
  @min_properties = args[:min_properties] if args.key?(:min_properties)
  @minimum = args[:minimum] if args.key?(:minimum)
  @nullable = args[:nullable] if args.key?(:nullable)
  @pattern = args[:pattern] if args.key?(:pattern)
  @properties = args[:properties] if args.key?(:properties)
  @property_ordering = args[:property_ordering] if args.key?(:property_ordering)
  @ref = args[:ref] if args.key?(:ref)
  @required = args[:required] if args.key?(:required)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end