Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Optional.
-
#any_of ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema>
Optional.
-
#default ⇒ Object
Optional.
-
#defs ⇒ Hash<String,Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema>
Optional.
-
#description ⇒ String
Optional.
-
#enum ⇒ Array<String>
Optional.
-
#example ⇒ Object
Optional.
-
#format ⇒ String
Optional.
-
#items ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema
Defines the schema of input and output data.
-
#max_items ⇒ Fixnum
Optional.
-
#max_length ⇒ Fixnum
Optional.
-
#max_properties ⇒ Fixnum
Optional.
-
#maximum ⇒ Float
Optional.
-
#min_items ⇒ Fixnum
Optional.
-
#min_length ⇒ Fixnum
Optional.
-
#min_properties ⇒ Fixnum
Optional.
-
#minimum ⇒ Float
Optional.
-
#nullable ⇒ Boolean
(also: #nullable?)
Optional.
-
#pattern ⇒ String
Optional.
-
#properties ⇒ Hash<String,Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema>
Optional.
-
#property_ordering ⇒ Array<String>
Optional.
-
#ref ⇒ String
Optional.
-
#required ⇒ Array<String>
Optional.
-
#title ⇒ String
Optional.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Schema
constructor
A new instance of GoogleCloudAiplatformV1beta1Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Schema
Returns a new instance of GoogleCloudAiplatformV1beta1Schema.
3229 3230 3231 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3229 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_properties ⇒ Object
Optional. If type is OBJECT, specifies how to handle properties not
defined in properties. If it is a boolean false, no additional properties
are allowed. If it is a schema, additional properties are allowed if they
conform to the schema.
Corresponds to the JSON property additionalProperties
3076 3077 3078 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3076 def additional_properties @additional_properties end |
#any_of ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema>
Optional. The instance must be valid against any (one or more) of the
subschemas listed in any_of.
Corresponds to the JSON property anyOf
3082 3083 3084 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3082 def any_of @any_of end |
#default ⇒ Object
Optional. Default value to use if the field is not specified.
Corresponds to the JSON property default
3087 3088 3089 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3087 def default @default end |
#defs ⇒ Hash<String,Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema>
Optional. defs provides a map of schema definitions that can be reused by
ref elsewhere in the schema. Only allowed at root level of the schema.
Corresponds to the JSON property defs
3093 3094 3095 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3093 def defs @defs end |
#description ⇒ String
Optional. Description of the schema.
Corresponds to the JSON property description
3098 3099 3100 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3098 def description @description end |
#enum ⇒ Array<String>
Optional. Possible values of the field. This field can be used to restrict a
value to a fixed set of values. To mark a field as an enum, set format to
enum and provide the list of possible values in enum. For example: 1. To
define directions: type:STRING, format:enum, enum:["EAST", "NORTH", "SOUTH",
"WEST"] 2. To define apartment numbers: type:INTEGER, format:enum, enum:["
101", "201", "301"]
Corresponds to the JSON property enum
3108 3109 3110 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3108 def enum @enum end |
#example ⇒ Object
Optional. Example of an instance of this schema.
Corresponds to the JSON property example
3113 3114 3115 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3113 def example @example end |
#format ⇒ String
Optional. The format of the data. For NUMBER type, format can be float or
double. For INTEGER type, format can be int32 or int64. For STRING
type, format can be email, byte, date, date-time, password, and
other formats to further refine the data type.
Corresponds to the JSON property format
3121 3122 3123 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3121 def format @format end |
#items ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema
Defines the schema of input and output data. This is a subset of the OpenAPI
3.0 Schema Object.
Corresponds to the JSON property items
3127 3128 3129 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3127 def items @items end |
#max_items ⇒ Fixnum
Optional. If type is ARRAY, max_items specifies the maximum number of
items in an array.
Corresponds to the JSON property maxItems
3133 3134 3135 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3133 def max_items @max_items end |
#max_length ⇒ Fixnum
Optional. If type is STRING, max_length specifies the maximum length of
the string.
Corresponds to the JSON property maxLength
3139 3140 3141 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3139 def max_length @max_length end |
#max_properties ⇒ Fixnum
Optional. If type is OBJECT, max_properties specifies the maximum number
of properties that can be provided.
Corresponds to the JSON property maxProperties
3145 3146 3147 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3145 def max_properties @max_properties end |
#maximum ⇒ Float
Optional. If type is INTEGER or NUMBER, maximum specifies the maximum
allowed value.
Corresponds to the JSON property maximum
3151 3152 3153 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3151 def maximum @maximum end |
#min_items ⇒ Fixnum
Optional. If type is ARRAY, min_items specifies the minimum number of
items in an array.
Corresponds to the JSON property minItems
3157 3158 3159 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3157 def min_items @min_items end |
#min_length ⇒ Fixnum
Optional. If type is STRING, min_length specifies the minimum length of
the string.
Corresponds to the JSON property minLength
3163 3164 3165 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3163 def min_length @min_length end |
#min_properties ⇒ Fixnum
Optional. If type is OBJECT, min_properties specifies the minimum number
of properties that can be provided.
Corresponds to the JSON property minProperties
3169 3170 3171 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3169 def min_properties @min_properties end |
#minimum ⇒ Float
Optional. If type is INTEGER or NUMBER, minimum specifies the minimum
allowed value.
Corresponds to the JSON property minimum
3175 3176 3177 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3175 def minimum @minimum end |
#nullable ⇒ Boolean Also known as: nullable?
Optional. Indicates if the value of this field can be null.
Corresponds to the JSON property nullable
3180 3181 3182 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3180 def nullable @nullable end |
#pattern ⇒ String
Optional. If type is STRING, pattern specifies a regular expression that
the string must match.
Corresponds to the JSON property pattern
3187 3188 3189 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3187 def pattern @pattern end |
#properties ⇒ Hash<String,Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Schema>
Optional. If type is OBJECT, properties is a map of property names to
schema definitions for each property of the object.
Corresponds to the JSON property properties
3193 3194 3195 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3193 def properties @properties end |
#property_ordering ⇒ Array<String>
Optional. Order of properties displayed or used where order matters. This is
not a standard field in OpenAPI specification, but can be used to control the
order of properties.
Corresponds to the JSON property propertyOrdering
3200 3201 3202 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3200 def property_ordering @property_ordering end |
#ref ⇒ String
Optional. Allows referencing another schema definition to use in place of this
schema. The value must be a valid reference to a schema in defs. For example,
the following schema defines a reference to a schema node named "Pet": type:
object properties: pet: ref: #/defs/Pet defs: Pet: type: object properties:
name: type: string The value of the "pet" property is a reference to the
schema node named "Pet". See details in https://json-schema.org/understanding-
json-schema/structuring
Corresponds to the JSON property ref
3211 3212 3213 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3211 def ref @ref end |
#required ⇒ Array<String>
Optional. If type is OBJECT, required lists the names of properties that
must be present.
Corresponds to the JSON property required
3217 3218 3219 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3217 def required @required end |
#title ⇒ String
Optional. Title for the schema.
Corresponds to the JSON property title
3222 3223 3224 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3222 def title @title end |
#type ⇒ String
Optional. Data type of the schema field.
Corresponds to the JSON property type
3227 3228 3229 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3227 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3234 def update!(**args) @additional_properties = args[:additional_properties] if args.key?(:additional_properties) @any_of = args[:any_of] if args.key?(:any_of) @default = args[:default] if args.key?(:default) @defs = args[:defs] if args.key?(:defs) @description = args[:description] if args.key?(:description) @enum = args[:enum] if args.key?(:enum) @example = args[:example] if args.key?(:example) @format = args[:format] if args.key?(:format) @items = args[:items] if args.key?(:items) @max_items = args[:max_items] if args.key?(:max_items) @max_length = args[:max_length] if args.key?(:max_length) @max_properties = args[:max_properties] if args.key?(:max_properties) @maximum = args[:maximum] if args.key?(:maximum) @min_items = args[:min_items] if args.key?(:min_items) @min_length = args[:min_length] if args.key?(:min_length) @min_properties = args[:min_properties] if args.key?(:min_properties) @minimum = args[:minimum] if args.key?(:minimum) @nullable = args[:nullable] if args.key?(:nullable) @pattern = args[:pattern] if args.key?(:pattern) @properties = args[:properties] if args.key?(:properties) @property_ordering = args[:property_ordering] if args.key?(:property_ordering) @ref = args[:ref] if args.key?(:ref) @required = args[:required] if args.key?(:required) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |