Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Segment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

A segment of the content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Segment

Returns a new instance of GoogleCloudAiplatformV1beta1Segment.



3325
3326
3327
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Output only. The end index of the segment in the Part, measured in bytes. This marks the end of the segment and is exclusive, meaning the segment includes content up to, but not including, the byte at this index. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


3305
3306
3307
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3305

def end_index
  @end_index
end

#part_indexFixnum

Output only. The index of the Part object that this segment belongs to. This is useful for associating the segment with a specific part of the content. Corresponds to the JSON property partIndex

Returns:

  • (Fixnum)


3311
3312
3313
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3311

def part_index
  @part_index
end

#start_indexFixnum

Output only. The start index of the segment in the Part, measured in bytes. This marks the beginning of the segment and is inclusive, meaning the byte at this index is the first byte of the segment. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


3318
3319
3320
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3318

def start_index
  @start_index
end

#textString

Output only. The text of the segment. Corresponds to the JSON property text

Returns:

  • (String)


3323
3324
3325
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3323

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3330
3331
3332
3333
3334
3335
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3330

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @part_index = args[:part_index] if args.key?(:part_index)
  @start_index = args[:start_index] if args.key?(:start_index)
  @text = args[:text] if args.key?(:text)
end