Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Tool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Tool details that the model may use to generate response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. A Tool object should contain exactly one type of Tool (e.g FunctionDeclaration, Retrieval or GoogleSearchRetrieval).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tool

Returns a new instance of GoogleCloudAiplatformV1beta1Tool.



4002
4003
4004
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_executionGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolCodeExecution

Tool that executes code generated by the model, and automatically returns the result to the model. See also ExecutableCode and CodeExecutionResult, which are input and output to this tool. Corresponds to the JSON property codeExecution



3942
3943
3944
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3942

def code_execution
  @code_execution
end

#computer_useGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolComputerUse

Tool to support computer use. Corresponds to the JSON property computerUse



3947
3948
3949
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3947

def computer_use
  @computer_use
end

#enterprise_web_searchGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1EnterpriseWebSearch

Tool to search public web data, powered by Vertex AI Search and Sec4 compliance. Corresponds to the JSON property enterpriseWebSearch



3953
3954
3955
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3953

def enterprise_web_search
  @enterprise_web_search
end

#exa_ai_searchGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolExaAiSearch

ExaAiSearch tool type. A tool that uses the Exa.ai search engine for grounding. Corresponds to the JSON property exaAiSearch



3958
3959
3960
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3958

def exa_ai_search
  @exa_ai_search
end

#function_declarationsArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionDeclaration>

Optional. Function tool type. One or more function declarations to be passed to the model along with the current user query. Model may decide to call a subset of these functions by populating FunctionCall in the response. User should provide a FunctionResponse for each function call in the next turn. Based on the function responses, Model will generate the final response back to the user. Maximum 512 function declarations can be provided. Corresponds to the JSON property functionDeclarations



3968
3969
3970
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3968

def function_declarations
  @function_declarations
end

#google_mapsGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GoogleMaps

Tool to retrieve public maps data for grounding, powered by Google. Corresponds to the JSON property googleMaps



3973
3974
3975
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3973

def google_maps
  @google_maps
end

#google_searchGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolGoogleSearch

GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google. Corresponds to the JSON property googleSearch



3979
3980
3981
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3979

def google_search
  @google_search
end

#google_search_retrievalGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GoogleSearchRetrieval

Tool to retrieve public web data for grounding, powered by Google. Corresponds to the JSON property googleSearchRetrieval



3984
3985
3986
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3984

def google_search_retrieval
  @google_search_retrieval
end

#parallel_ai_searchGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolParallelAiSearch

ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding. Corresponds to the JSON property parallelAiSearch



3990
3991
3992
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3990

def parallel_ai_search
  @parallel_ai_search
end

#retrievalGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Retrieval

Defines a retrieval tool that model can call to access external knowledge. Corresponds to the JSON property retrieval



3995
3996
3997
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3995

def retrieval
  @retrieval
end

#url_contextGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1UrlContext

Tool to support URL context. Corresponds to the JSON property urlContext



4000
4001
4002
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4000

def url_context
  @url_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4007

def update!(**args)
  @code_execution = args[:code_execution] if args.key?(:code_execution)
  @computer_use = args[:computer_use] if args.key?(:computer_use)
  @enterprise_web_search = args[:enterprise_web_search] if args.key?(:enterprise_web_search)
  @exa_ai_search = args[:exa_ai_search] if args.key?(:exa_ai_search)
  @function_declarations = args[:function_declarations] if args.key?(:function_declarations)
  @google_maps = args[:google_maps] if args.key?(:google_maps)
  @google_search = args[:google_search] if args.key?(:google_search)
  @google_search_retrieval = args[:google_search_retrieval] if args.key?(:google_search_retrieval)
  @parallel_ai_search = args[:parallel_ai_search] if args.key?(:parallel_ai_search)
  @retrieval = args[:retrieval] if args.key?(:retrieval)
  @url_context = args[:url_context] if args.key?(:url_context)
end