Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Tool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Tool details that the model may use to generate response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. A Tool object should contain exactly one type of Tool (e.g FunctionDeclaration, Retrieval or GoogleSearchRetrieval).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tool

Returns a new instance of GoogleCloudAiplatformV1beta1Tool.



3616
3617
3618
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3616

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_executionGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolCodeExecution

Tool that executes code generated by the model, and automatically returns the result to the model. See also ExecutableCode and CodeExecutionResult, which are input and output to this tool. Corresponds to the JSON property codeExecution



3556
3557
3558
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3556

def code_execution
  @code_execution
end

#computer_useGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolComputerUse

Tool to support computer use. Corresponds to the JSON property computerUse



3561
3562
3563
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3561

def computer_use
  @computer_use
end

#enterprise_web_searchGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1EnterpriseWebSearch

Tool to search public web data, powered by Vertex AI Search and Sec4 compliance. Corresponds to the JSON property enterpriseWebSearch



3567
3568
3569
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3567

def enterprise_web_search
  @enterprise_web_search
end

#exa_ai_searchGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolExaAiSearch

ExaAiSearch tool type. A tool that uses the Exa.ai search engine for grounding. Corresponds to the JSON property exaAiSearch



3572
3573
3574
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3572

def exa_ai_search
  @exa_ai_search
end

#function_declarationsArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionDeclaration>

Optional. Function tool type. One or more function declarations to be passed to the model along with the current user query. Model may decide to call a subset of these functions by populating FunctionCall in the response. User should provide a FunctionResponse for each function call in the next turn. Based on the function responses, Model will generate the final response back to the user. Maximum 512 function declarations can be provided. Corresponds to the JSON property functionDeclarations



3582
3583
3584
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3582

def function_declarations
  @function_declarations
end

#google_mapsGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GoogleMaps

Tool to retrieve public maps data for grounding, powered by Google. Corresponds to the JSON property googleMaps



3587
3588
3589
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3587

def google_maps
  @google_maps
end

#google_searchGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolGoogleSearch

GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google. Corresponds to the JSON property googleSearch



3593
3594
3595
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3593

def google_search
  @google_search
end

#google_search_retrievalGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GoogleSearchRetrieval

Tool to retrieve public web data for grounding, powered by Google. Corresponds to the JSON property googleSearchRetrieval



3598
3599
3600
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3598

def google_search_retrieval
  @google_search_retrieval
end

#parallel_ai_searchGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolParallelAiSearch

ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding. Corresponds to the JSON property parallelAiSearch



3604
3605
3606
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3604

def parallel_ai_search
  @parallel_ai_search
end

#retrievalGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Retrieval

Defines a retrieval tool that model can call to access external knowledge. Corresponds to the JSON property retrieval



3609
3610
3611
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3609

def retrieval
  @retrieval
end

#url_contextGoogle::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1UrlContext

Tool to support URL context. Corresponds to the JSON property urlContext



3614
3615
3616
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3614

def url_context
  @url_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3621
3622
3623
3624
3625
3626
3627
3628
3629
3630
3631
3632
3633
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3621

def update!(**args)
  @code_execution = args[:code_execution] if args.key?(:code_execution)
  @computer_use = args[:computer_use] if args.key?(:computer_use)
  @enterprise_web_search = args[:enterprise_web_search] if args.key?(:enterprise_web_search)
  @exa_ai_search = args[:exa_ai_search] if args.key?(:exa_ai_search)
  @function_declarations = args[:function_declarations] if args.key?(:function_declarations)
  @google_maps = args[:google_maps] if args.key?(:google_maps)
  @google_search = args[:google_search] if args.key?(:google_search)
  @google_search_retrieval = args[:google_search_retrieval] if args.key?(:google_search_retrieval)
  @parallel_ai_search = args[:parallel_ai_search] if args.key?(:parallel_ai_search)
  @retrieval = args[:retrieval] if args.key?(:retrieval)
  @url_context = args[:url_context] if args.key?(:url_context)
end