Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Tool
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Tool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
Tool details that the model may use to generate response. A Tool is a piece
of code that enables the system to interact with external systems to perform
an action, or set of actions, outside of knowledge and scope of the model. A
Tool object should contain exactly one type of Tool (e.g FunctionDeclaration,
Retrieval or GoogleSearchRetrieval).
Instance Attribute Summary collapse
-
#code_execution ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolCodeExecution
Tool that executes code generated by the model, and automatically returns the result to the model.
-
#computer_use ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolComputerUse
Tool to support computer use.
-
#enterprise_web_search ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1EnterpriseWebSearch
Tool to search public web data, powered by Vertex AI Search and Sec4 compliance.
-
#function_declarations ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionDeclaration>
Optional.
-
#google_maps ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GoogleMaps
Tool to retrieve public maps data for grounding, powered by Google.
-
#google_search ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolGoogleSearch
GoogleSearch tool type.
-
#google_search_retrieval ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GoogleSearchRetrieval
Tool to retrieve public web data for grounding, powered by Google.
-
#parallel_ai_search ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolParallelAiSearch
ParallelAiSearch tool type.
-
#retrieval ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Retrieval
Defines a retrieval tool that model can call to access external knowledge.
-
#url_context ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1UrlContext
Tool to support URL context.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tool
constructor
A new instance of GoogleCloudAiplatformV1beta1Tool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1Tool
Returns a new instance of GoogleCloudAiplatformV1beta1Tool.
3463 3464 3465 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolCodeExecution
Tool that executes code generated by the model, and automatically returns the
result to the model. See also [ExecutableCode]and [CodeExecutionResult] which
are input and output to this tool.
Corresponds to the JSON property codeExecution
3408 3409 3410 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3408 def code_execution @code_execution end |
#computer_use ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolComputerUse
Tool to support computer use.
Corresponds to the JSON property computerUse
3413 3414 3415 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3413 def computer_use @computer_use end |
#enterprise_web_search ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1EnterpriseWebSearch
Tool to search public web data, powered by Vertex AI Search and Sec4
compliance.
Corresponds to the JSON property enterpriseWebSearch
3419 3420 3421 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3419 def enterprise_web_search @enterprise_web_search end |
#function_declarations ⇒ Array<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1FunctionDeclaration>
Optional. Function tool type. One or more function declarations to be passed
to the model along with the current user query. Model may decide to call a
subset of these functions by populating FunctionCall in the response. User
should provide a FunctionResponse for each function call in the next turn.
Based on the function responses, Model will generate the final response back
to the user. Maximum 512 function declarations can be provided.
Corresponds to the JSON property functionDeclarations
3429 3430 3431 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3429 def function_declarations @function_declarations end |
#google_maps ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GoogleMaps
Tool to retrieve public maps data for grounding, powered by Google.
Corresponds to the JSON property googleMaps
3434 3435 3436 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3434 def google_maps @google_maps end |
#google_search ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolGoogleSearch
GoogleSearch tool type. Tool to support Google Search in Model. Powered by
Google.
Corresponds to the JSON property googleSearch
3440 3441 3442 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3440 def google_search @google_search end |
#google_search_retrieval ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1GoogleSearchRetrieval
Tool to retrieve public web data for grounding, powered by Google.
Corresponds to the JSON property googleSearchRetrieval
3445 3446 3447 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3445 def google_search_retrieval @google_search_retrieval end |
#parallel_ai_search ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolParallelAiSearch
ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for
grounding.
Corresponds to the JSON property parallelAiSearch
3451 3452 3453 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3451 def parallel_ai_search @parallel_ai_search end |
#retrieval ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1Retrieval
Defines a retrieval tool that model can call to access external knowledge.
Corresponds to the JSON property retrieval
3456 3457 3458 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3456 def retrieval @retrieval end |
#url_context ⇒ Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1UrlContext
Tool to support URL context.
Corresponds to the JSON property urlContext
3461 3462 3463 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3461 def url_context @url_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3468 def update!(**args) @code_execution = args[:code_execution] if args.key?(:code_execution) @computer_use = args[:computer_use] if args.key?(:computer_use) @enterprise_web_search = args[:enterprise_web_search] if args.key?(:enterprise_web_search) @function_declarations = args[:function_declarations] if args.key?(:function_declarations) @google_maps = args[:google_maps] if args.key?(:google_maps) @google_search = args[:google_search] if args.key?(:google_search) @google_search_retrieval = args[:google_search_retrieval] if args.key?(:google_search_retrieval) @parallel_ai_search = args[:parallel_ai_search] if args.key?(:parallel_ai_search) @retrieval = args[:retrieval] if args.key?(:retrieval) @url_context = args[:url_context] if args.key?(:url_context) end |