Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolComputerUse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Tool to support computer use.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolComputerUse

Returns a new instance of GoogleCloudAiplatformV1beta1ToolComputerUse.



3823
3824
3825
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_prompt_injection_detectionBoolean Also known as: enable_prompt_injection_detection?

Optional. Enables the prompt injection detection check on computer-use request. Corresponds to the JSON property enablePromptInjectionDetection

Returns:

  • (Boolean)


3805
3806
3807
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3805

def enable_prompt_injection_detection
  @enable_prompt_injection_detection
end

#environmentString

Required. The environment being operated. Corresponds to the JSON property environment

Returns:

  • (String)


3811
3812
3813
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3811

def environment
  @environment
end

#excluded_predefined_functionsArray<String>

Optional. By default, predefined functions are included in the final model call. Some of them can be explicitly excluded from being automatically included. This can serve two purposes: 1. Using a more restricted / different action space. 2. Improving the definitions / instructions of predefined functions. Corresponds to the JSON property excludedPredefinedFunctions

Returns:

  • (Array<String>)


3821
3822
3823
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3821

def excluded_predefined_functions
  @excluded_predefined_functions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3828
3829
3830
3831
3832
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3828

def update!(**args)
  @enable_prompt_injection_detection = args[:enable_prompt_injection_detection] if args.key?(:enable_prompt_injection_detection)
  @environment = args[:environment] if args.key?(:environment)
  @excluded_predefined_functions = args[:excluded_predefined_functions] if args.key?(:excluded_predefined_functions)
end