Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1ToolParallelAiSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1ToolParallelAiSearch

Returns a new instance of GoogleCloudAiplatformV1beta1ToolParallelAiSearch.



3605
3606
3607
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3605

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_keyString

Optional. The API key for ParallelAiSearch. If an API key is not provided, the system will attempt to verify access by checking for an active Parallel.ai subscription through the Google Cloud Marketplace. See https://docs.parallel. ai/search/search-quickstart for more details. Corresponds to the JSON property apiKey

Returns:

  • (String)


3591
3592
3593
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3591

def api_key
  @api_key
end

#custom_configsHash<String,Object>

Optional. Custom configs for ParallelAiSearch. This field can be used to pass any parameter from the Parallel.ai Search API. See the Parallel.ai documentation for the full list of available parameters and their usage: https: //docs.parallel.ai/api-reference/search-beta/search Currently only source_policy, excerpts, max_results, mode, fetch_policy can be set via this field. For example: "source_policy": "include_domains": ["google. com", "wikipedia.org"], "exclude_domains": ["example.com"] , "fetch_policy": "max_age_seconds": 3600 Corresponds to the JSON property customConfigs

Returns:

  • (Hash<String,Object>)


3603
3604
3605
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3603

def custom_configs
  @custom_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3610
3611
3612
3613
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 3610

def update!(**args)
  @api_key = args[:api_key] if args.key?(:api_key)
  @custom_configs = args[:custom_configs] if args.key?(:custom_configs)
end