Class: Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VertexAiSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

Retrieve from Vertex AI Search datastore or engine for grounding. datastore and engine are mutually exclusive. See https://cloud.google.com/products/agent- builder

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1beta1VertexAiSearch

Returns a new instance of GoogleCloudAiplatformV1beta1VertexAiSearch.



4127
4128
4129
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4127

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_store_specsArray<Google::Apis::FirebasemlV2beta::GoogleCloudAiplatformV1beta1VertexAiSearchDataStoreSpec>

Specifications that define the specific DataStores to be searched, along with configurations for those data stores. This is only considered for Engines with multiple data stores. It should only be set if engine is used. Corresponds to the JSON property dataStoreSpecs



4100
4101
4102
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4100

def data_store_specs
  @data_store_specs
end

#datastoreString

Optional. Fully-qualified Vertex AI Search data store resource ID. Format: projects/project/locations/location/collections/collection/dataStores/ dataStore` Corresponds to the JSON propertydatastore`

Returns:

  • (String)


4107
4108
4109
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4107

def datastore
  @datastore
end

#engineString

Optional. Fully-qualified Vertex AI Search engine resource ID. Format: projects/project/locations/location/collections/collection/engines/ engine` Corresponds to the JSON propertyengine`

Returns:

  • (String)


4114
4115
4116
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4114

def engine
  @engine
end

#filterString

Optional. Filter strings to be passed to the search API. Corresponds to the JSON property filter

Returns:

  • (String)


4119
4120
4121
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4119

def filter
  @filter
end

#max_resultsFixnum

Optional. Number of search results to return per query. The default value is

  1. The maximumm allowed value is 10. Corresponds to the JSON property maxResults

Returns:

  • (Fixnum)


4125
4126
4127
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4125

def max_results
  @max_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4132
4133
4134
4135
4136
4137
4138
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4132

def update!(**args)
  @data_store_specs = args[:data_store_specs] if args.key?(:data_store_specs)
  @datastore = args[:datastore] if args.key?(:datastore)
  @engine = args[:engine] if args.key?(:engine)
  @filter = args[:filter] if args.key?(:filter)
  @max_results = args[:max_results] if args.key?(:max_results)
end