Class: Google::Apis::FirebasemlV2beta::LatLng
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::LatLng
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.
Instance Attribute Summary collapse
-
#latitude ⇒ Float
The latitude in degrees.
-
#longitude ⇒ Float
The longitude in degrees.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LatLng
constructor
A new instance of LatLng.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LatLng
Returns a new instance of LatLng.
4607 4608 4609 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#latitude ⇒ Float
The latitude in degrees. It must be in the range [-90.0, +90.0].
Corresponds to the JSON property latitude
4600 4601 4602 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4600 def latitude @latitude end |
#longitude ⇒ Float
The longitude in degrees. It must be in the range [-180.0, +180.0].
Corresponds to the JSON property longitude
4605 4606 4607 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4605 def longitude @longitude end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4612 4613 4614 4615 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4612 def update!(**args) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) end |