Class: Google::Apis::FirebasemlV2beta::LatLng

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb

Overview

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LatLng

Returns a new instance of LatLng.



4368
4369
4370
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4368

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#latitudeFloat

The latitude in degrees. It must be in the range [-90.0, +90.0]. Corresponds to the JSON property latitude

Returns:

  • (Float)


4361
4362
4363
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4361

def latitude
  @latitude
end

#longitudeFloat

The longitude in degrees. It must be in the range [-180.0, +180.0]. Corresponds to the JSON property longitude

Returns:

  • (Float)


4366
4367
4368
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4366

def longitude
  @longitude
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4373
4374
4375
4376
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4373

def update!(**args)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
end