Class: Google::Apis::FirebasemlV2beta::LatLng
- Inherits:
-
Object
- Object
- Google::Apis::FirebasemlV2beta::LatLng
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseml_v2beta/classes.rb,
lib/google/apis/firebaseml_v2beta/representations.rb,
lib/google/apis/firebaseml_v2beta/representations.rb
Overview
An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.
Instance Attribute Summary collapse
-
#latitude ⇒ Float
The latitude in degrees.
-
#longitude ⇒ Float
The longitude in degrees.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LatLng
constructor
A new instance of LatLng.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LatLng
Returns a new instance of LatLng.
4347 4348 4349 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4347 def initialize(**args) update!(**args) end |
Instance Attribute Details
#latitude ⇒ Float
The latitude in degrees. It must be in the range [-90.0, +90.0].
Corresponds to the JSON property latitude
4340 4341 4342 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4340 def latitude @latitude end |
#longitude ⇒ Float
The longitude in degrees. It must be in the range [-180.0, +180.0].
Corresponds to the JSON property longitude
4345 4346 4347 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4345 def longitude @longitude end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4352 4353 4354 4355 |
# File 'lib/google/apis/firebaseml_v2beta/classes.rb', line 4352 def update!(**args) @latitude = args[:latitude] if args.key?(:latitude) @longitude = args[:longitude] if args.key?(:longitude) end |